@@ -1,8 +1,7 @@
 <?php
-/* $Id: db_operations.php,v 2.10.2.2 2005/07/02 12:11:16 lem9 Exp $ */
+/* $Id: db_operations.php,v 2.22 2005/11/18 12:50:49 cybot_tm Exp $ */
 // vim: expandtab sw=4 ts=4 sts=4:
 
-require_once('./libraries/grab_globals.lib.php');
 require_once('./libraries/common.lib.php');
 require_once('./libraries/mysql_charsets.lib.php');
 /**
@@ -14,8 +13,6 @@ if (isset($db) &&
 
     require_once('./libraries/tbl_move_copy.php');
 
-    $force_queryframe_reload = TRUE;
-
     if (isset($db_rename) && $db_rename == 'true') {
         $move = TRUE;
     } else {
@@ -134,52 +131,29 @@ if (empty($is_info)) {
 if (PMA_MYSQL_INT_VERSION >= 40101) {
     $db_collation = PMA_getDbCollation($db);
 }
-?>
+if (PMA_MYSQL_INT_VERSION < 50002 || (PMA_MYSQL_INT_VERSION >= 50002 && $db != 'information_schema')) {
+    $is_information_schema = FALSE;
+} else {
+    $is_information_schema = TRUE;
+}
 
-<table border="0" cellpadding="2" cellspacing="0">
-    <!-- Create a new table -->
-        <form method="post" action="tbl_create.php" onsubmit="return (emptyFormElements(this, 'table') && checkFormElementInRange(this, 'num_fields', 1))">
-     <tr>
-     <td class="tblHeaders" colspan="3" nowrap="nowrap"><?php
-        echo PMA_generate_common_hidden_inputs($db);
-        if($cfg['PropertiesIconic']){ echo '<img src="' . $pmaThemeImage . 'b_newtbl.png" border="0" width="16" height="16" hspace="2" align="middle" />'; }
-        // if you want navigation:
-        $strDBLink = '<a href="' . $GLOBALS['cfg']['DefaultTabDatabase'] . '?' . PMA_generate_common_url() . '&amp;db=' . urlencode($GLOBALS['db']) . '">'
-                   . htmlspecialchars($GLOBALS['db']) . '</a>';
-        // else use
-        // $strDBLink = htmlspecialchars($db);
-echo '             ' . sprintf($strCreateNewTable, $strDBLink) . ':&nbsp;' . "\n";
-echo '     </td></tr>';
-echo '     <tr bgcolor="'.$cfg['BgcolorOne'].'"><td nowrap="nowrap">';
-echo '             ' . $strName . ':&nbsp;' . "\n";
-echo '     </td>';
-echo '     <td nowrap="nowrap">';
-echo '             ' . '<input type="text" name="table" maxlength="64" size="30" class="textfield" />';
-echo '     </td><td>&nbsp;</td></tr>';
-echo '     <tr bgcolor="'.$cfg['BgcolorOne'].'"><td nowrap="nowrap">';
-echo '             ' . $strFields . ':&nbsp;' . "\n";
-echo '     </td>';
-echo '     <td nowrap="nowrap">';
-echo '             ' . '<input type="text" name="num_fields" size="2" class="textfield" />' . "\n";
-echo '     </td>';
-echo '     <td align="right">';
-echo '             ' . '&nbsp;<input type="submit" value="' . $strGo . '" />' . "\n";
-echo '     </td> </tr>';
-echo '        </form>';
+if (!$is_information_schema) {
 
-echo '<table border="0" cellpadding="2" cellspacing="0">';
-if ($cfgRelation['commwork']) {
+    require('./libraries/display_create_table.lib.php');
+
+    echo '<table border="0" cellpadding="2" cellspacing="0">';
+    if ($cfgRelation['commwork']) {
 ?>
     <!-- Alter/Enter db-comment -->
         <tr><td colspan="3"><img src="<?php echo $GLOBALS['pmaThemeImage'] . 'spacer.png'; ?>" width="1" height="1" border="0" alt="" /></td></tr>
 
         <tr>
         <td colspan="3" class="tblHeaders"><?php
-    if ($cfg['PropertiesIconic']) {
-        echo '<img src="' . $pmaThemeImage . 'b_comment.png" border="0" width="16" height="16" hspace="2" align="middle" />';
-    }
-    echo $strDBComment;
-    $comment = PMA_getComments($db);
+        if ($cfg['PropertiesIconic']) {
+            echo '<img src="' . $pmaThemeImage . 'b_comment.png" border="0" width="16" height="16" hspace="2" align="middle" />';
+        }
+        echo $strDBComment;
+        $comment = PMA_getComments($db);
         ?></td></tr>
                                 <form method="post" action="db_operations.php">
         <tr bgcolor="<?php echo $cfg['BgcolorOne']; ?>">
@@ -191,7 +165,7 @@ if ($cfgRelation['commwork']) {
          </td></tr>
         </form>
 <?php
-}
+    }
 ?>
     <!-- Rename database -->
         <tr><td colspan="3"><img src="<?php echo $GLOBALS['pmaThemeImage'] . 'spacer.png'; ?>" width="1" height="1" border="0" alt="" /></td></tr>
@@ -234,9 +208,11 @@ if ($cfgRelation['commwork']) {
                 <input type="radio" name="what" value="structure" id="radio_copy_structure" style="vertical-align: middle" /><label for="radio_copy_structure"><?php echo $strStrucOnly; ?></label>&nbsp;&nbsp;<br />
                 <input type="radio" name="what" value="data" id="radio_copy_data" checked="checked" style="vertical-align: middle" /><label for="radio_copy_data"><?php echo $strStrucData; ?></label>&nbsp;&nbsp;<br />
                 <input type="radio" name="what" value="dataonly" id="radio_copy_dataonly" style="vertical-align: middle" /><label for="radio_copy_dataonly"><?php echo $strDataOnly; ?></label>&nbsp;&nbsp;<br />
+                
 
                 <input type="checkbox" name="create_database_before_copying" value="1" id="checkbox_create_database_before_copying" style="vertical-align: middle" checked="checked" /><label for="checkbox_create_database_before_copying"><?php echo $strCreateDatabaseBeforeCopying; ?></label><br />
-                <input type="checkbox" name="auto_increment" value="1" id="checkbox_auto_increment" style="vertical-align: middle" /><label for="checkbox_auto_increment"><?php echo $strAddAutoIncrement; ?></label><br />
+                <input type="checkbox" name="drop_if_exists" value="true" id="checkbox_drop" style="vertical-align: middle" /><label for="checkbox_drop"><?php echo $strStrucDrop; ?></label>&nbsp;&nbsp;<br />
+                <input type="checkbox" name="sql_auto_increment" value="1" id="checkbox_auto_increment" style="vertical-align: middle" /><label for="checkbox_auto_increment"><?php echo $strAddAutoIncrement; ?></label><br />
                 <input type="checkbox" name="constraints" value="1" id="checkbox_constraints" style="vertical-align: middle" /><label for="checkbox_constraints"><?php echo $strAddConstraints; ?></label><br />
                 <?php
                     if (isset($_COOKIE) && isset($_COOKIE['pma_switch_to_new']) && $_COOKIE['pma_switch_to_new'] == 'true') {
@@ -253,42 +229,43 @@ if ($cfgRelation['commwork']) {
 
 <?php
 
-if (PMA_MYSQL_INT_VERSION >= 40101) {
+    if (PMA_MYSQL_INT_VERSION >= 40101) {
     // MySQL supports setting default charsets / collations for databases since
     // version 4.1.1.
-    echo '    <!-- Change database charset -->' . "\n"
-       . '    <tr><td colspan="3"><img src="' . $GLOBALS['pmaThemeImage'] . 'spacer.png' . '" width="1" height="1" border="0" alt="" /></td></tr>' . "\n"
-       . '    <tr><td colspan="3" class="tblHeaders">';
-    if ($cfg['PropertiesIconic']) {
-        echo '<img src="' . $pmaThemeImage . 's_asci.png" border="0" width="16" height="16" hspace="2" align="middle" />';
+        echo '    <!-- Change database charset -->' . "\n"
+           . '    <tr><td colspan="3"><img src="' . $GLOBALS['pmaThemeImage'] . 'spacer.png' . '" width="1" height="1" border="0" alt="" /></td></tr>' . "\n"
+           . '    <tr><td colspan="3" class="tblHeaders">';
+        if ($cfg['PropertiesIconic']) {
+            echo '<img src="' . $pmaThemeImage . 's_asci.png" border="0" width="16" height="16" hspace="2" align="middle" />';
+        }
+        echo '      <label for="select_db_collation">' . $strCollation . '</label>:&nbsp;' . "\n"
+           . '    </td></tr>' . "\n"
+           . '        <form method="post" action="./db_operations.php">' . "\n"
+           . '    <tr bgcolor="' . $cfg['BgcolorOne'] . '"><td colspan="2" nowrap="nowrap">'
+           . PMA_generate_common_hidden_inputs($db, $table, 3)
+           . PMA_generateCharsetDropdownBox(PMA_CSDROPDOWN_COLLATION, 'db_collation', 'select_db_collation', $db_collation, FALSE, 3)
+           . '    </td><td align="right">'
+           . '            <input type="submit" name="submitcollation" value="' . $strGo . '" style="vertical-align: middle" />' . "\n"
+           . '    </td></tr>' . "\n"
+           . '        </form>' . "\n"
+           . '         ' . "\n\n";
     }
-    echo '      <label for="select_db_collation">' . $strCollation . '</label>:&nbsp;' . "\n"
-       . '    </td></tr>' . "\n"
-       . '        <form method="post" action="./db_operations.php">' . "\n"
-       . '    <tr bgcolor="' . $cfg['BgcolorOne'] . '"><td colspan="2" nowrap="nowrap">'
-       . PMA_generate_common_hidden_inputs($db, $table, 3)
-       . PMA_generateCharsetDropdownBox(PMA_CSDROPDOWN_COLLATION, 'db_collation', 'select_db_collation', $db_collation, FALSE, 3)
-       . '    </td><td align="right">'
-       . '            <input type="submit" name="submitcollation" value="' . $strGo . '" style="vertical-align: middle" />' . "\n"
-       . '    </td></tr>' . "\n"
-       . '        </form>' . "\n"
-       . '         ' . "\n\n";
-}
+    
+    echo '</table>';
+
+    if ( $num_tables > 0
+        && !$cfgRelation['allworks'] && $cfg['PmaNoRelation_DisableWarning'] == FALSE) {
+        echo '<div class="error"><h1>' . $strError . '</h1>'
+            . sprintf( $strRelationNotWorking, '<a href="' . $cfg['PmaAbsoluteUri'] . 'chk_rel.php?' . $url_query . '">',  '</a>')
+            . '</div>';
+    } // end if
+} // end if (!$is_information_schema)
+// not sure about leaving the PDF dialog for information_schema
 
-if ($num_tables > 0
-    && !$cfgRelation['allworks'] && $cfg['PmaNoRelation_DisableWarning'] == FALSE) {
-    echo '<tr><td colspan="3"><img src="' . $GLOBALS['pmaThemeImage'] . 'spacer.png' . '" width="1" height="1" border="0" alt="" /></td></tr>'
-        . '<tr><th colspan="3" class="tblHeadError"><div class="errorhead">' . $strError . '</div></th></tr>'
-        . '<tr><td colspan="3" class="tblError">'
-        . sprintf(wordwrap($strRelationNotWorking,65,'<br />'), '<a href="' . $cfg['PmaAbsoluteUri'] . 'chk_rel.php?' . $url_query . '">',  '</a>')
-        . '</td></tr>';
-} // end if
 ?>
-</table>
-
 <form method="post" action="pdf_schema.php">
 <?php
-// is this OK to check for 'class' support?
+
 if ($num_tables > 0) {
     $takeaway = $url_query . '&amp;table=' . urlencode($table);
 }
