@@ -1,5 +1,5 @@
 <?php
-/* $Id: chinese_traditional-utf-8.inc.php,v 2.40.2.1 2005/06/30 17:03:18 lem9 Exp $ */
+/* $Id: chinese_traditional-utf-8.inc.php,v 2.66 2005/10/30 10:03:49 nijel Exp $ */
 
 /**
  * Last translation by: Siu Sun <siusun@best-view.net>
@@ -58,6 +58,7 @@ $strAfterInsertSame = '返回這頁';
 $strAll = '全部';
 $strAllTableSameWidth = '以相同寬度顯示所有資料表?';
 $strAlterOrderBy = '根據欄位內容排序記錄';
+$strAndThen = '然後';
 $strAnIndex = '索引已經新增到 %s';
 $strAnalyzeTable = '分析資料表';
 $strAnd = '與';
@@ -90,7 +91,6 @@ $strBinaryLog = '二進制記錄';
 $strBookmarkAllUsers = '所有用者可讀取此書籤';
 $strBookmarkDeleted = '書籤已經刪除.';
 $strBookmarkLabel = '書籤名稱';
-$strBookmarkOptions = '書籤選項';
 $strBookmarkQuery = 'SQL 語法書籤';
 $strBookmarkThis = '將此 SQL 語法加入書籤';
 $strBookmarkView = '查看';
@@ -115,7 +115,6 @@ $strCantLoadRecodeIconv = '未能讀取 iconv 或重新編碼程式來作文字
 $strCantRenameIdxToPrimary = '無法將索引更名為 PRIMARY!';
 $strCantUseRecodeIconv = '當文編碼模組讀取後,未能使用 iconv, libiconv 或 recode_string 功能. 請檢查您的 php 設定.';
 $strCardinality = '組別';
-$strCarriage = '歸位: \\r';
 $strCaseInsensitive = '大小寫不相符';
 $strCaseSensitive = '大小寫相符';
 $strCentralEuropean = '中歐語';
@@ -323,7 +322,6 @@ $strHungarian = '匈牙利語';
 $strIcelandic = '冰島語'; 
 $strId = 'ID'; // use eng
 $strIdxFulltext = '全文檢索';
-$strIfYouWish = '如果您要指定資料匯入的欄位，請輸入用逗號隔開的欄位名稱';
 $strIgnore = '忽略';
 $strIgnoreInserts = '使用忽略加入 (insert)'; 
 $strIgnoringFile = '忽略檔案 %s';
@@ -352,14 +350,15 @@ $strInnodbStat = 'InnoDB 狀態';
 $strInsecureMySQL = '設定檔內有關設定 (root登入及沒有密碼) 與預設的 MySQL 權限戶口相同。 MySQL 伺服器在這預設的設定運行的話會很容易被入侵，您應更改有關設定去防止安全漏洞。';
 $strInsert = '新增';
 $strInsertAsNewRow = '儲存為新記錄';
-$strInsertBookmarkTitle = '請輸入書籤標題';
 $strInsertNewRow = '新增一筆記錄';
-$strInsertTextfiles = '將文字檔資料匯入資料表';
 $strInsertedRowId = '新增資料列 id:';
 $strInsertedRows = '新增列數:';
-$strInstructions = '指令';
 $strInternalNotNecessary = '* 當內部關聯在 InnoDB 已存在時是無需要的.';
 $strInternalRelations = '內部關聯';
+$strInvalidColumnCount = '欄位數目需要大於零.';
+$strInvalidFieldAddCount = '你最少要加入一個欄位.';
+$strInvalidFieldCount = '資料表最少需要有一個欄位.';
+$strInvalidRowNumber = '%d 不是一個有效的列數數目.';
 
 $strJapanese = '日語';
 $strJumpToDB = '跳到資料庫 &quot;%s&quot;.';
@@ -385,13 +384,10 @@ $strLatexStructure = '資料表 __TABLE__ 結構';
 $strLatvian = '拉脫維亞語';
 $strLengthSet = '長度/集合*';
 $strLimitNumRows = '筆記錄/每頁';
-$strLineFeed = '換行: \\n';
 $strLinesTerminatedBy = '「下一行」使用字元：';
 $strLinkNotFound = '找不到連結';
 $strLinksTo = '連結到';
 $strLithuanian = '立陶宛語';
-$strLoadExplanation = '最佳模式是由系統自動檢查, 如果錯誤, 您可自由更改.';
-$strLoadMethod = 'LOAD 模式';
 $strLocalhost = '本地';
 $strLocationTextfile = '文字檔案的位置';
 $strLogPassword = '密碼:';
@@ -419,12 +415,10 @@ $strMbOverloadWarning = '你在 PHP 設定內啟動了 mbstring.func_overload 
 $strModifications = '修改已儲存';
 $strModify = '修改';
 $strModifyIndexTopic = '修改索引';
-$strMoreStatusVars = '更多狀況資訊';
 $strMoveTable = '移動資料表到：(格式為 資料庫名稱<b>.</b>資料表名稱)';
 $strMoveTableOK = '資料表 %s 已經移動到 %s.';
 $strMoveTableSameNames = '無法移動到相同資料表!';
 $strMultilingual = '多語言';
-$strMustSelectFile = '您應選擇需要新增的檔案.';
 $strMyISAMDataPointerSize = '資料指標大小';
 $strMyISAMDataPointerSizeDesc = '預設的資料指標大小時當以 CREATE TABLE 建立 MyISAM 資料表, 而並無設定最大列數 (MAX_ROWS) 時, 將會以位完組為設定大小';
 $strMyISAMMaxExtraSortFileSize = '臨時檔案建立索引時最大的容量';
@@ -447,7 +441,6 @@ $strMySQLShowStatus = '顯示 MySQL 執行狀態';
 $strMySQLShowVars = '顯示 MySQL 系統變數';
 
 $strName = '名稱';
-$strNeedPrimaryKey = '您需要在此資料表設定主鍵 (Primary Key)';
 $strNext = '下一個';
 $strNo = ' 否 ';
 $strNoActivity = '由於已閒置了達 %s 秒, 請重新登入';
@@ -466,7 +459,6 @@ $strNoPassword = '不用密碼';
 $strNoPermission = 'Web 伺服器沒有權限儲存檔案 %s.';
 $strNoPhp = '移除 PHP 程式碼';
 $strNoPrivileges = '沒有權限';
-$strNoQuery = '沒有 SQL 語法!';
 $strNoRights = '您現在沒有足夠的權限!';
 $strNoRowsSelected = '並無資料列已選擇';
 $strNoSpace = '空間不足儲存檔案 %s.';
@@ -478,19 +470,15 @@ $strNone = '不適用';
 $strNotNumber = '這不是一個數字!';
 $strNotOK = '未能確定';
 $strNotSet = '<b>%s</b> 資料表找不到或還未在 %s 設定';
-$strNotValidNumber = '不是有效的列數!';
 $strNull = 'Null'; //should expressed in English
 $strNumSearchResultsInTable = '%s 項資料符合 - 於資料表 <i>%s</i>';
 $strNumSearchResultsTotal = '<b>總計:</b> <i>%s</i> 項資料符合';
 $strNumTables = '個資料表';
 
 $strOK = '確定';
-$strOftenQuotation = '最常用的是引號，「非必須」表示只有 char 和 varchar 欄位會被包括起來';
 $strOperations = '管理';
 $strOperator = '操作員';
 $strOptimizeTable = '最佳化資料表';
-$strOptionalControls = '非必要選項，用來讀寫特殊字元';
-$strOptionally = '非必須';
 $strOr = '或';
 $strOverhead = '多餘';
 $strOverwriteExisting = '覆寫已存在檔案';
@@ -530,7 +518,6 @@ $strPrintView = '列印檢視';
 $strPrintViewFull = '列印檢視 (顯示完整文字)';
 $strPrivDescAllPrivileges = '包括所有權限除了授權 (GRNANT).';
 $strPrivDescAlter = '容許修改現有資料表的結構.';
-$strPrivDescAlterDb = '容許更改現有資料表的結構、文字編碼及校對.';
 $strPrivDescAlterRoutine = '容許修改及刪除儲存程序.';
 $strPrivDescCreateDb = '容許建立新資料庫及資料表.';
 $strPrivDescCreateRoutine = '容許建立儲存程序';
@@ -599,7 +586,6 @@ $strRenameDatabaseOK = '資料庫 %s 已更改名稱為 %s';
 $strRenameTable = '將資料表改名為';
 $strRenameTableOK = '已經將資料表 %s 改名成 %s';
 $strRepairTable = '修復資料表';
-$strReplace = '取代';
 $strReplaceNULLBy = '將 NULL 取代為';
 $strReplaceTable = '以檔案取代資料表資料';
 $strReset = '重置';
@@ -609,7 +595,6 @@ $strRevokeAndDelete = '廢除使用者所有有效之權限並刪除.';
 $strRevokeAndDeleteDescr = '使用者仍然有 USAGE 權限直至權限資料表更新讀取.';
 $strRevokeMessage = '您已移除這位使用者的權限: %s';
 $strRomanian = '羅馬尼亞語';
-$strRoutines = '程序 (Routines)';
 $strRowLength = '資料列長度';
 $strRowSize = '資料列大小';
 $strRows = '資料列列數';
@@ -729,9 +714,6 @@ $strTakeIt = '選用';
 $strTblPrivileges = '指定資料表權限';
 $strTextAreaLength = ' 由於長度限制<br /> 此欄位不能編輯 ';
 $strThai = '泰語';
-$strTheContent = '檔案內容已經匯入資料表';
-$strTheContents = '檔案內容將會取代選定的資料表中具有相同主鍵或唯一鍵的記錄';
-$strTheTerminator = '分隔欄位的字元';
 $strTheme = '款式';
 $strThisHost = '指定主機';
 $strThisNotDirectory = '這並不是一個目錄';
@@ -744,6 +726,7 @@ $strTraditionalChinese = '繁體中文';
 $strTraditionalSpanish = '傳統西班牙語';
 $strTraffic = '流量';
 $strTransformation_application_octetstream__download = '於欄位顯示連線來下載二進制資料. 第一個選項是二進制的檔案名稱. 第二個選項可設定可用的欄位名稱用作檔案名稱. 如您設定了第二個選項, 第一個選項無需設定';
+$strTransformation_application_octetstream__hex = '以十六進制方式顯示.';
 $strTransformation_image_jpeg__inline = '顯示可按式圖像; 選項; 寬度,高度[以像素為單位] (保時原有比例)';
 $strTransformation_image_jpeg__link = '顯示圖像的連線 (直接下載).';
 $strTransformation_image_png__inline = '參看 image/jpeg: 內建';
@@ -814,5 +797,165 @@ $strYes = ' 是 ';
 $strZeroRemovesTheLimit = '註: 設定這些選項為 0 (零) 可解除限制.';
 $strZip = '"zipped"';
 
-$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data.';  //to translate
+$strInvalidAuthMethod = 'Invalid authentication method set in configuration:';  //to translate
+$strRunSQLQueryOnServer = 'Run SQL query/queries on server %s';  //to translate
+$strCSV = 'CSV';  //to translate
+$strImport = 'Import';  //to translate
+$strImportFormat = 'Format of imported file';  //to translate
+$strFileToImport = 'File to import';  //to translate
+$strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
+$strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
+$strEnclosingOptional = 'Enclosing of fields is optional';  //to translate
+$strCSVImportOptions = 'CSV options';  //to translate
+$strPartialImport = 'Partial import';  //to translate
+$strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate
+$strTimeoutPassed = 'Script timeout passed, if you want to finish import, please resubmit same file and import will resume.';  //to translate
+$strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
+$strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
+$strUnsupportedCompressionDetected = 'You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.';  //to translate
+$strNothingToImport = 'You didn\'t enter any data to import!';  //to translate
+$strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
+$strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
+$strInvalidColumn = 'Invalid column (%s) specified!';  //to translate
+$strInvalidCSVInput = 'Invalid CSV input, could not parse!';  //to translate
+$strNoFilesFoundInZip = 'No files found inside ZIP archive!';  //to translate
+$strErrorInZipFile = 'Error in ZIP archive:';  //to translate
+$strFlushQueryCache = 'Flush query cache';  //to translate
+$strFlushTables = 'Flush (close) all tables';  //to translate
+$strHandler = 'Handler';  //to translate
+$strJoins = 'Joins';  //to translate
+$strKeyCache = 'Key cache';  //to translate
+$strMaxConnects = 'max. concurrent connections';  //to translate
+$strQueryCache = 'Query cache';  //to translate
+$strReplication = 'Replication';  //to translate
+$strServerStatusDelayedInserts = 'Delayed inserts';  //to translate
+$strShowOpenTables = 'Show open tables';  //to translate
+$strShowSlaveHosts = 'Show slave hosts';  //to translate
+$strShowSlaveStatus = 'Show slave status';  //to translate
+$strShowStatusReset = 'Reset';  //to translate
+$strShowStatusBinlog_cache_disk_useDescr = 'The number of transactions that used the temporary binary log cache but that exceeded the value of binlog_cache_size and used a temporary file to store statements from the transaction.';  //to translate
+$strShowStatusBinlog_cache_useDescr = 'The number of transactions that used the temporary binary log cache.';  //to translate
+$strShowStatusCreated_tmp_disk_tablesDescr = 'The number of temporary tables on disk created automatically by the server while executing statements. If Created_tmp_disk_tables is big, you may want to increase the tmp_table_size  value to cause temporary tables to be memory-based instead of disk-based.';  //to translate
+$strShowStatusCreated_tmp_filesDescr = 'How many temporary files mysqld has created.';  //to translate
+$strShowStatusCreated_tmp_tablesDescr = 'The number of in-memory temporary tables created automatically by the server while executing statements.';  //to translate
+$strShowStatusDelayed_errorsDescr = 'The number of rows written with INSERT DELAYED for which some error occurred (probably duplicate key).';  //to translate
+$strShowStatusDelayed_insert_threadsDescr = 'The number of INSERT DELAYED handler threads in use. Every different table on which one uses INSERT DELAYED gets its own thread.';  //to translate
+$strShowStatusDelayed_writesDescr = 'The number of INSERT DELAYED rows written.';  //to translate
+$strShowStatusFlush_commandsDescr  = 'The number of executed FLUSH statements.';  //to translate
+$strShowStatusHandler_commitDescr = 'The number of internal COMMIT statements.';  //to translate
+$strShowStatusHandler_deleteDescr = 'The number of times a row was deleted from a table.';  //to translate
+$strShowStatusHandler_discoverDescr = 'The MySQL server can ask the NDB Cluster storage engine if it knows about a table with a given name. This is called discovery. Handler_discover indicates the number of time tables have been discovered.';  //to translate
+$strShowStatusHandler_read_firstDescr = 'The number of times the first entry was read from an index. If this is high, it suggests that the server is doing a lot of full index scans; for example, SELECT col1 FROM foo, assuming that col1 is indexed.';  //to translate
+$strShowStatusHandler_read_keyDescr = 'The number of requests to read a row based on a key. If this is high, it is a good indication that your queries and tables are properly indexed.';  //to translate
+$strShowStatusHandler_read_nextDescr = 'The number of requests to read the next row in key order. This is incremented if you are querying an index column with a range constraint or if you are doing an index scan.';  //to translate
+$strShowStatusHandler_read_prevDescr = 'The number of requests to read the previous row in key order. This read method is mainly used to optimize ORDER BY ... DESC.';  //to translate
+$strShowStatusHandler_read_rndDescr = 'The number of requests to read a row based on a fixed position. This is high if you are doing a lot of queries that require sorting of the result. You probably have a lot of queries that require MySQL to scan whole tables or you have joins that don\'t use keys properly.';  //to translate
+$strShowStatusHandler_read_rnd_nextDescr = 'The number of requests to read the next row in the data file. This is high if you are doing a lot of table scans. Generally this suggests that your tables are not properly indexed or that your queries are not written to take advantage of the indexes you have.';  //to translate
+$strShowStatusHandler_rollbackDescr = 'The number of internal ROLLBACK statements.';  //to translate
+$strShowStatusHandler_updateDescr = 'The number of requests to update a row in a table.';  //to translate
+$strShowStatusHandler_writeDescr = 'The number of requests to insert a row in a table.';  //to translate
+$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'The number of pages containing data (dirty or clean).';  //to translate
+$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'The number of pages currently dirty.';  //to translate
+$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'The number of buffer pool pages that have been requested to be flushed.';  //to translate
+$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'The number of free pages.';  //to translate
+$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'The number of latched pages in InnoDB buffer pool. These are pages currently being read or written or that can\'t be flushed or removed for some other reason.';  //to translate
+$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'The number of pages busy because they have been allocated for administrative overhead such as row locks or the adaptive hash index. This value can also be calculated as Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';  //to translate
+$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'Total size of buffer pool, in pages.';  //to translate
+$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'The number of "random" read-aheads InnoDB initiated. This happens when a query is to scan a large portion of a table but in random order.';  //to translate
+$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'The number of sequential read-aheads InnoDB initiated. This happens when InnoDB does a sequential full table scan.';  //to translate
+$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'The number of logical read requests InnoDB has done.';  //to translate
+$strShowStatusInnodb_buffer_pool_readsDescr = 'The number of logical reads that InnoDB could not satisfy from buffer pool and had to do a single-page read.';  //to translate
+$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Normally, writes to the InnoDB buffer pool happen in the background. However, if it\'s necessary to read or create a page and no clean pages are available, it\'s necessary to wait for pages to be flushed first. This counter counts instances of these waits. If the buffer pool size was set properly, this value should be small.';  //to translate
+$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'The number writes done to the InnoDB buffer pool.';  //to translate
+$strShowStatusInnodb_data_fsyncsDescr = 'The number of fsync() operations so far.';  //to translate
+$strShowStatusInnodb_data_pending_fsyncsDescr = 'The current number of pending fsync() operations.';  //to translate
+$strShowStatusInnodb_data_pending_readsDescr = 'The current number of pending reads.';  //to translate
+$strShowStatusInnodb_data_pending_writesDescr = 'The current number of pending writes.';  //to translate
+$strShowStatusInnodb_data_readDescr = 'The amount of data read so far, in bytes.';  //to translate
+$strShowStatusInnodb_data_readsDescr = 'The total number of data reads.';  //to translate
+$strShowStatusInnodb_data_writesDescr = 'The total number of data writes.';  //to translate
+$strShowStatusInnodb_data_writtenDescr = 'The amount of data written so far, in bytes.';  //to translate
+$strShowStatusInnodb_dblwr_pages_writtenDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
+$strShowStatusInnodb_dblwr_writesDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
+$strShowStatusInnodb_log_waitsDescr = 'The number of waits we had because log buffer was too small and we had to wait for it to be flushed before continuing.';  //to translate
+$strShowStatusInnodb_log_write_requestsDescr = 'The number of log write requests.';  //to translate
+$strShowStatusInnodb_log_writesDescr = 'The number of physical writes to the log file.';  //to translate
+$strShowStatusInnodb_os_log_fsyncsDescr = 'The number of fsyncs writes done to the log file.';  //to translate
+$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'The number of pending log file fsyncs.';  //to translate
+$strShowStatusInnodb_os_log_pending_writesDescr = 'Pending log file writes.';  //to translate
+$strShowStatusInnodb_os_log_writtenDescr = 'The number of bytes written to the log file.';  //to translate
+$strShowStatusInnodb_page_sizeDescr = 'The compiled-in InnoDB page size (default 16KB). Many values are counted in pages; the page size allows them to be easily converted to bytes.';  //to translate
+$strShowStatusInnodb_pages_createdDescr = 'The number of pages created.';  //to translate
+$strShowStatusInnodb_pages_readDescr = 'The number of pages read.';  //to translate
+$strShowStatusInnodb_pages_writtenDescr = 'The number of pages written.';  //to translate
+$strShowStatusInnodb_row_lock_current_waitsDescr = 'The number of row locks currently being waited for.';  //to translate
+$strShowStatusInnodb_row_lock_timeDescr = 'The total time spent in acquiring row locks, in milliseconds.';  //to translate
+$strShowStatusInnodb_row_lock_time_avgDescr = 'The average time to acquire a row lock, in milliseconds.';  //to translate
+$strShowStatusInnodb_row_lock_time_maxDescr = 'The maximum time to acquire a row lock, in milliseconds.';  //to translate
+$strShowStatusInnodb_row_lock_waitsDescr = 'The number of times a row lock had to be waited for.';  //to translate
+$strShowStatusInnodb_rows_deletedDescr = 'The number of rows deleted from InnoDB tables.';  //to translate
+$strShowStatusInnodb_rows_insertedDescr = 'The number of rows inserted in InnoDB tables.';  //to translate
+$strShowStatusInnodb_rows_readDescr = 'The number of rows read from InnoDB tables.';  //to translate
+$strShowStatusInnodb_rows_updatedDescr = 'The number of rows updated in InnoDB tables.';  //to translate
+$strShowStatusKey_blocks_not_flushedDescr = 'The number of key blocks in the key cache that have changed but haven\'t yet been flushed to disk. It used to be known as Not_flushed_key_blocks.';  //to translate
+$strShowStatusKey_blocks_unusedDescr = 'The number of unused blocks in the key cache. You can use this value to determine how much of the key cache is in use.';  //to translate
+$strShowStatusKey_blocks_usedDescr = 'The number of used blocks in the key cache. This value is a high-water mark that indicates the maximum number of blocks that have ever been in use at one time.';  //to translate
+$strShowStatusKey_read_requestsDescr = 'The number of requests to read a key block from the cache.';  //to translate
+$strShowStatusKey_readsDescr = 'The number of physical reads of a key block from disk. If Key_reads is big, then your key_buffer_size value is probably too small. The cache miss rate can be calculated as Key_reads/Key_read_requests.';  //to translate
+$strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
+$strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
+$strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
+$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
+$strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
+$strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
+$strShowStatusOpen_tablesDescr = 'The number of tables that are open.';  //to translate
+$strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
+$strShowStatusQcache_free_blocksDescr = 'The number of free memory blocks in query cache.';  //to translate
+$strShowStatusQcache_free_memoryDescr = 'The amount of free memory for query cache.';  //to translate
+$strShowStatusQcache_hitsDescr = 'The number of cache hits.';  //to translate
+$strShowStatusQcache_insertsDescr = 'The number of queries added to the cache.';  //to translate
+$strShowStatusQcache_lowmem_prunesDescr = 'The number of queries that have been removed from the cache to free up memory for caching new queries. This information can help you tune the query cache size. The query cache uses a least recently used (LRU) strategy to decide which queries to remove from the cache.';  //to translate
+$strShowStatusQcache_not_cachedDescr = 'The number of non-cached queries (not cachable, or not cached due to the query_cache_type setting).';  //to translate
+$strShowStatusQcache_queries_in_cacheDescr = 'The number of queries registered in the cache.';  //to translate
+$strShowStatusQcache_total_blocksDescr = 'The total number of blocks in the query cache.';  //to translate
+$strShowStatusRpl_statusDescr = 'The status of failsafe replication (not yet implemented).';  //to translate
+$strShowStatusSelect_full_joinDescr = 'The number of joins that do not use indexes. If this value is not 0, you should carefully check the indexes of your tables.';  //to translate
+$strShowStatusSelect_full_range_joinDescr = 'The number of joins that used a range search on a reference table.';  //to translate
+$strShowStatusSelect_rangeDescr = 'The number of joins that used ranges on the first table. (It\'s normally not critical even if this is big.)';  //to translate
+$strShowStatusSelect_range_checkDescr = 'The number of joins without keys that check for key usage after each row. (If this is not 0, you should carefully check the indexes of your tables.)';  //to translate
+$strShowStatusSelect_scanDescr = 'The number of joins that did a full scan of the first table.';  //to translate
+$strShowStatusSlave_open_temp_tablesDescr = 'The number of temporary tables currently open by the slave SQL thread.';  //to translate
+$strShowStatusSlave_retried_transactionsDescr = 'Total (since startup) number of times the replication slave SQL thread has retried transactions.';  //to translate
+$strShowStatusSlave_runningDescr = 'This is ON if this server is a slave that is connected to a master.';  //to translate
+$strShowStatusSlow_launch_threadsDescr = 'The number of threads that have taken more than slow_launch_time seconds to create.';  //to translate
+$strShowStatusSlow_queriesDescr = 'The number of queries that have taken more than long_query_time seconds.';  //to translate
+$strShowStatusSort_merge_passesDescr = 'The number of merge passes the sort algorithm has had to do. If this value is large, you should consider increasing the value of the sort_buffer_size system variable.';  //to translate
+$strShowStatusSort_rangeDescr = 'The number of sorts that were done with ranges.';  //to translate
+$strShowStatusSort_rowsDescr = 'The number of sorted rows.';  //to translate
+$strShowStatusSort_scanDescr = 'The number of sorts that were done by scanning the table.';  //to translate
+$strShowStatusTable_locks_immediateDescr = 'The number of times that a table lock was acquired immediately.';  //to translate
+$strShowStatusTable_locks_waitedDescr = 'The number of times that a table lock could not be acquired immediately and a wait was needed. If this is high, and you have performance problems, you should first optimize your queries, and then either split your table or tables or use replication.';  //to translate
+$strShowStatusThreads_cachedDescr = 'The number of threads in the thread cache. The cache hit rate can be calculated as Threads_created/Connections. If this value is red you should raise your thread_cache_size.';  //to translate
+$strShowStatusThreads_connectedDescr = 'The number of currently open connections.';  //to translate
+$strShowStatusThreads_createdDescr = 'The number of threads created to handle connections. If Threads_created is big, you may want to increase the thread_cache_size value. (Normally this doesn\'t give a notable performance improvement if you have a good thread implementation.)';  //to translate
+$strShowStatusThreads_runningDescr = 'The number of threads that are not sleeping.';  //to translate
+$strSorting = 'Sorting';  //to translate
+$strTempData = 'Temporary data';  //to translate
+$strThreads = 'Threads';  //to translate
+$strLDI = 'CSV using LOAD DATA';  //to translate
+$strLDILocal = 'Use LOCAL keyword';  //to translate
+$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
+$strInvalidLDIImport = 'This plugin does not support compressed imports!';  //to translate
+$strTableAlreadyExists = 'Table %s already exists!';  //to translate
+$strTransactionCoordinator = 'Transaction coordinator';  //to translate
+$strNumberOfFields = 'Number of fields';  //to translate
+$strShowingBookmark = 'Showing bookmark';  //to translate
+$strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';  //to translate
+$strDeleteNoUsersSelected = 'No users selected for deleting!';  //to translate
+$strPrivDescMaxUserConnections = 'Limits the number of simultaneous connections the user may have.';  //to translate
+$strMaximalQueryLength = 'Maximal length of created query';  //to translate
+$strBookmarkCreated = 'Bookmark %s created';  //to translate
+$strBookmarkReplace = 'Replace existing bookmark of same name';  //to translate
+$strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate
+$strEsperanto = 'Esperanto';  //to translate
 ?>
