@@ -1,5 +1,5 @@
 <?php
-/* $Id: german-iso-8859-15.inc.php,v 2.7.2.1 2005/06/30 17:24:51 lem9 Exp $ */
+/* $Id: german-iso-8859-15.inc.php,v 2.35 2005/11/17 13:15:25 cybot_tm Exp $ */
 
 /**
  * For suggestions concerning this file please contact
@@ -91,7 +91,6 @@ $strBinLogServerId = 'Server-ID';
 $strBookmarkAllUsers = 'Diese gespeicherte SQL-Abfrage fr jeden Benutzer verfgbar machen';
 $strBookmarkDeleted = 'SQL-Abfrage wurde gelscht.';
 $strBookmarkLabel = 'Titel';
-$strBookmarkOptions = 'Optionen zur Speicherung der SQL-Abfrage';
 $strBookmarkQuery = 'Gespeicherte SQL-Abfrage';
 $strBookmarkThis = 'SQL-Abfrage speichern';
 $strBookmarkView = 'Nur zeigen';
@@ -110,13 +109,13 @@ $strBzError = 'phpMyAdmin konnte die Datei wegen eines Fehler in der Bz2-Erweite
 $strBzip = 'BZip-komprimiert';
 
 $strCalendar = 'Kalender';
+$strCanNotLoadImportPlugins = 'Die Import-Plugins konnten nicht geladen werden. Bitte berprfen Sie Ihre phpMyAdmin-Installation.';
 $strCannotLogin = 'Die Anmeldung am MySQL-Server ist fehlgeschlagen.';
-$strCantLoad = 'Die Erweiterung &quot;%s&quot; kann nicht geladen werden.<br />Bitte berprfen Sie Ihre PHP-Konfiguration.';
+$strCantLoad = 'Die Erweiterung [a@http://php.net/%1$s@Documentation][em]%1$s[/em][/a] kann nicht geladen werden. Bitte berprfen Sie Ihre PHP-Konfiguration.';
 $strCantLoadRecodeIconv = 'Die PHP-Erweiterungen iconv und recode, welche fr die Zeichensatzkonvertierung bentigt werden, konnten nicht geladen werden. Bitte ndern Sie Ihre PHP-Konfiguration und aktivieren Sie diese Erweiterungen oder deaktivieren Sie die Zeichensatzkonvertierung in phpMyAdmin.';
 $strCantRenameIdxToPrimary = 'Kann Index nicht in PRIMARY umbenennen!';
 $strCantUseRecodeIconv = 'Weder die iconv- noch libiconv- oder recode_string-Funktion konnte verwandt werden, obwohl die bentigten php-Erweiterungen angeblich geladen wurden. Bitte berprfen Sie Ihre PHP-Konfiguration.';
 $strCardinality = 'Kardinalitt';
-$strCarriage = 'Wagenrcklauf \\r';
 $strCaseInsensitive = 'case-insensitive';
 $strCaseSensitive = 'case-sensitive';
 $strCentralEuropean = 'Mitteleuropisch';
@@ -149,7 +148,7 @@ $strComments = 'Kommentare';
 $strCompatibleHashing = 'MySQL&nbsp;4.0 kompatibel';
 $strCompleteInserts = 'Vollstndige \'INSERT\'s';
 $strCompression = 'Kompression';
-$strConfigFileError = 'phpMyAdmin konnte Ihre Konfigurationsdatei nicht verarbeiten!<br />Dies kann passieren, wenn der PHP-Parser Syntaxfehler in ihr findet oder sie nicht existiert.<br />Bitte rufen Sie die Konfigurationsdatei ben den unteren Link direkt auf und lesen Sie die PHP-Fehlermeldungen, die Sie erhalten. Meistens fehlt blo irgendwo ein Anfhrungszeichen oder Semikolon.<br />Wenn Sie eine leere Seite erhalten, ist Ihre Konfigurationsdatei in Ordnung.';
+$strConfigFileError = 'phpMyAdmin konnte Ihre Konfigurationsdatei nicht verarbeiten!<br />Dies kann passieren, wenn der PHP-Parser Syntaxfehler in ihr findet oder sie nicht existiert.<br />Bitte rufen Sie die Konfigurationsdatei ber den unteren Link direkt auf und lesen Sie die PHP-Fehlermeldungen, die Sie erhalten. Meistens fehlt blo irgendwo ein Anfhrungszeichen oder Semikolon.<br />Wenn Sie eine leere Seite erhalten, ist Ihre Konfigurationsdatei in Ordnung.';
 $strConfigureTableCoord = 'Bitte konfigurieren Sie die Koordinaten fr die Tabelle %s';
 $strConnectionError = 'Die Verbindung konnte aufgrund von ungltigen Einstellungen nicht hergestellt werden.';
 $strConnections = 'Verbindungen';
@@ -260,6 +259,7 @@ $strEnglish = 'Englisch';
 $strEnglishPrivileges = ' Anmerkung: MySQL-Rechte werden auf Englisch angegeben. ';
 $strError = 'Fehler';
 $strEscapeWildcards = 'Platzhalter _ und % sollten mit einem \ escaped werden, um das gewnschte Sonderzeichen einzubinden';
+$strEsperanto = 'Esperanto';
 $strEstonian = 'Estnisch';
 $strExcelEdition = 'Excel-Ausgabe';
 $strExcelOptions = 'Excel-Optionen';
@@ -284,7 +284,7 @@ $strFileNameTemplateHelp = 'Benutzen Sie __DB__ fr den Datenbanknamen, __TABLE__
 $strFileNameTemplateRemember = 'Konvention merken';
 $strFixed = 'starr';
 $strFlushPrivilegesNote = 'Anmerkung: phpMyAdmin liest die Benutzerprofile direkt aus den entsprechenden MySQL-Tabellen aus. Der Inhalt dieser Tabellen kann sich von den Benutzprofilen, die MySQL z.Zt. verwendet, unterscheiden, wenn manuelle nderungen vorgenommen wurden. In diesem Fall sollten Sie  %sdie Benutzerprofile neu laden%s bevor Sie fortfahren.';
-$strFlushTable = 'Leeren des Tabellenchaches ("FLUSH")';
+$strFlushTable = 'Leeren des Tabellencaches ("FLUSH")';
 $strFormat = 'Format';
 $strFormEmpty = 'Das Formular ist leer !';
 $strFreePages = 'Unbenutzte Seiten';
@@ -324,13 +324,11 @@ $strHungarian = 'Ungarisch';
 $strIcelandic = 'Islndisch';
 $strId = 'ID';
 $strIdxFulltext = 'Volltext';
-$strIfYouWish = 'Wenn Sie nur bestimmte Spalten importieren mchten, geben Sie diese bitte hier an.';
 $strIgnore = 'Ignorieren';
 $strIgnoreInserts = 'Fehlerbergehenden INSERT-Befehl verwenden';
 $strIgnoringFile = 'Die Datei %s wird ignoriert';
 $strImportDocSQL = 'docSQL-Dateien importieren';
 $strImportFiles = 'Dateiimport';
-$strImportFinished = 'Import beendet';
 $strIndexes = 'Indizes';
 $strIndexHasBeenDropped = 'Index %s wurde entfernt.';
 $strIndex = 'Index';
@@ -351,16 +349,14 @@ $strInnoDBPages = 'Seiten';
 $strInnodbStat = 'InnoDB-Status';
 $strInsecureMySQL = 'Ihre Konfigurationsdatei enthlt Einstellungen (Benutzer &quot;root&quot; ohne Passwort), welche denen des MySQL-Standardbenutzers entsprechen. Wird Ihr MySQL-Server mit diesen Einstellungen betrieben, so knnen Unbefugte leicht von auen auf ihn zugreifen. Sie sollten diese Sicherheitslcke unbedingt schlieen!';
 $strInsertAsNewRow = ' Als neuen Datensatz speichern ';
-$strInsertBookmarkTitle = 'Bitte benennen Sie Ihre gespeicherte Abfrage';
 $strInsertedRowId = 'Letzte automatisch eingefgte ID:';
 $strInsertedRows = 'Eingefgte Zeilen:';
 $strInsert = 'Einfgen';
 $strInsertNewRow = 'Neue Zeile einfgen';
-$strInsertTextfiles = 'Textdatei in Tabelle einfgen';
-$strInstructions = 'Befehle';
 $strInternalNotNecessary = '* Eine interne Beziehung ist nicht notwendig, wenn sie bereits im InnoDB-Format vorliegt.';
 $strInternalRelations = 'Interne Beziehungen';
 $strInUse = 'in Benutzung';
+$strInvalidFieldAddCount = 'Sie mssen mindestens ein Feld hinzufgen.';
 
 $strJapanese = 'Japanisch';
 $strJumpToDB = 'Zur Datenbank &quot;%s&quot; springen.';
@@ -384,15 +380,12 @@ $strLaTeX = 'LaTeX';
 $strLaTeXOptions = 'LaTeX-Optionen';
 $strLatexStructure = 'Struktur der Tabelle __TABLE__';
 $strLatvian = 'Lettisch';
-$strLengthSet = 'Lnge/Set*';
+$strLengthSet = 'Lnge/Set';
 $strLimitNumRows = 'Eintrge pro Seite';
-$strLineFeed = 'Zeilenvorschub: \\n';
 $strLinesTerminatedBy = 'Zeilen getrennt mit';
 $strLinkNotFound = 'Der Verweis wurde nicht gefunden.';
 $strLinksTo = 'Verweise';
 $strLithuanian = 'Litauisch';
-$strLoadExplanation = 'Die beste Methode zur Verarbeitung der hochgeladenen Datei durch MySQL ist standardmig aktiviert.  Whlen Sie bei Problemen bitte die andere Methode.';
-$strLoadMethod = 'LOAD-Methode';
 $strLocalhost = 'Lokal';
 $strLocationTextfile = 'Datei';
 $strLoginInformation = 'Logininformationen';
@@ -413,31 +406,29 @@ $strMIME_MIMEtype = 'MIME-Typ';
 $strMIME_nodescription = 'Fr diese Umwandlung ist keine Beschreibung verfgar.<br />Fr weitere Informationen wenden Sie sich bitte an den Autoren der Funktion &quot;%s&quot;.';
 $strMIME_transformation = 'Darstellungsumwandlung';
 $strMIME_transformation_note = 'Um eine Liste aller verfgbaren MIME-Typen-Umwandlungen und deren Optionen zu sehen, klicken Sie bitte auf %sUmwandlungen%s';
-$strMIME_transformation_options_note = 'Bitte die Werte fr die Umwandlungsoptionen in folgendem Format angeben:: \'a\',\'b\',\'c\'...<br />Wann immer Sie ein Backslash ("\") oder ein einfaches Anfhrungszeichen ("\'") verwenden,<br \>setzen Sie bitte ein Backslash vor das Zeichen.  (z.B.: \'\\\\xyz\' or \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Bitte die Werte fr die Umwandlungsoptionen in folgendem Format angeben: \'a\',\'b\',\'c\',... Wann immer Sie ein Backslash ("\") oder ein einfaches Anfhrungszeichen ("\'") verwenden, setzen Sie bitte ein Backslash vor das Zeichen. (z. B.: \'\\\\xyz\' oder \'a\\\'b\').';
 $strMIME_transformation_options = 'Umwandlungsoptionen';
 $strMIMETypesForTable = 'MIME TYPEN DER TABELLE';
 $strMIME_without = 'Kursiv dargestellte MIME-Typen besitzen keine untergliederten Umwandlungen.';
 $strModifications = 'nderungen gespeichert.';
 $strModifyIndexTopic = 'Index modifizieren';
 $strModify = 'Verndern';
-$strMoreStatusVars = 'Weitere Statusvariablen';
 $strMoveTableOK = 'Tabelle %s wurde nach %s verschoben.';
 $strMoveTableSameNames = 'Tabelle kann nicht mit gleichem Namen verschoben werden!';
 $strMoveTable = 'Verschiebe Tabelle nach (Datenbank<b>.</b>Tabellenname):';
 $strMultilingual = 'multilingual';
-$strMustSelectFile = 'Bitte geben Sie eine Datei an, die eingefgt werden soll.';
 $strMyISAMDataPointerSizeDesc = 'Standardmige Gre des Pointers, welcher von CREATE TABLE fr MyISAM-Tabellen verwendet wird, sofern die Option MAX_ROWS nicht angegeben wird.';
 $strMyISAMDataPointerSize = 'Gre des Datenpointers';
 $strMyISAMMaxExtraSortFileSizeDesc = 'Wenn das Erzeugen der temporren Datei fr schnelle Index-Erzeugung um diesen Wert grer sein wrde als die Benutzung des Schlssel-Caches, wird die Schlssel-Cache-Methode bevorzugt.';
 $strMyISAMMaxExtraSortFileSize = 'Maximum Gre temporrer Dateien bei Indexerstellung';
 $strMyISAMMaxSortFileSizeDesc = 'Die maximale Gre der temporren Datei, die MySQL benutzen darf, whrend es den Index erzeugt (whrend REPAIR, ALTER TABLE oder LOAD DATA INFILE).';
 $strMyISAMMaxSortFileSize = 'Maximale Gre temporrer Dateien beim Sortieren';
-$strMyISAMRecoverOptions = 'Autoreperatur-Modus'; 
+$strMyISAMRecoverOptions = 'Autoreperatur-Modus';
 $strMyISAMRecoverOptionsDesc = 'Der Modus der automatischen Wiederherstellung abgestrzter MyISAM-Tabellen, wie ber den Startparameter --myisam-recover angegeben.';
 $strMyISAMRepairThreadsDesc = 'Wenn dieser Wert grer als 1 ist, werden MyISAM-Tabellenindizes wrend einer Reperatur oder eines Sortierungsprozesses parallel erstellt (jeder Index in einem separaten Thread).';
 $strMyISAMRepairThreads = 'Reperaturthreads';
 $strMyISAMSortBufferSizeDesc = 'Der Puffer, der beim Sortieren des Indexes zugewiesen wird, wenn man ein REPAIR oder ausfhrt oder Indizes mit CREATE INDEX oder ALTER TABLE erzeugt.';
-$strMyISAMSortBufferSize = 'Gre des Sortierungspuffers'; 
+$strMyISAMSortBufferSize = 'Gre des Sortierungspuffers';
 $strMySQLCharset = 'MySQL-Zeichensatz';
 $strMySQLConnectionCollation = 'Zeichensatz / Kollation der MySQL-Verbindung';
 $strMySQLReloaded = 'Die MySQL-Benutzertabellen wurden neu geladen.';
@@ -448,7 +439,6 @@ $strMySQLShowStatus = 'MySQL-Laufzeit-Informationen anzeigen';
 $strMySQLShowVars = 'MySQL-System-Variablen anzeigen';
 
 $strName = 'Name';
-$strNeedPrimaryKey = 'Es sollte ein Primrschlssel fr diese Tabelle definiert werden.';
 $strNext = 'Nchste';
 $strNoActivity = 'Da Sie seit mindestens %s Sekunden inaktiv waren, wurden Sie automatisch abgemeldet. Bitte melden Sie sich erneut an.';
 $strNoDatabases = 'Keine Datenbanken';
@@ -468,7 +458,6 @@ $strNoPassword = 'Kein Kennwort';
 $strNoPermission = 'Der Webserver hat keine Schreibrechte um die Datei %s zu speichern.';
 $strNoPhp = 'ohne PHP-Code';
 $strNoPrivileges = 'Keine Rechte';
-$strNoQuery = 'Kein SQL-Befehl!';
 $strNoRights = 'Sie haben nicht genug Rechte um fortzufahren!';
 $strNoRowsSelected = 'Es wurden keine Datenstze ausgewhlt.';
 $strNoSpace = 'Zu wenig Speicherplatz um die Datei %s zu speichern.';
@@ -477,7 +466,6 @@ $strNoThemeSupport = 'Die Untersttzung fr Oberflchendesigns ist deaktiviert. Bit
 $strNotNumber = 'Das ist keine Zahl!';
 $strNotOK = 'fehlerhaft';
 $strNotSet = 'Die Tabelle <b>%s</b> wurde entweder nicht gefunden oder in der Kofigurationsdatei %s nicht gesetzt.';
-$strNotValidNumber = ' ist keine gltige Zeilennummer!';
 $strNoUsersFound = 'Es wurden keine Benutzer gefunden.';
 $strNoValidateSQL = 'SQL-Validierung umgehen';
 $strNull = 'Null';
@@ -485,13 +473,10 @@ $strNumSearchResultsInTable = '%s Treffer in der Tabelle <i>%s</i>';
 $strNumSearchResultsTotal = '<b>Insgesamt</b> <i>%s</i> Treffer';
 $strNumTables = 'Tabellen';
 
-$strOftenQuotation = 'Hufig Anfhrungszeichen. Optional bedeutet, dass nur Textfelder von den angegeben Zeichen eingeschlossen sind.';
 $strOK = 'OK';
 $strOperations = 'Operationen';
 $strOperator = 'Operator';
 $strOptimizeTable = 'Optimiere Tabelle';
-$strOptionalControls = 'Optional. Bestimmt, wie Sonderzeichen kenntlich gemacht werden.';
-$strOptionally = 'optional';
 $strOr = 'oder';
 $strOverhead = 'berhang';
 $strOverwriteExisting = 'Bestehende Datei(en) berschreiben';
@@ -592,7 +577,6 @@ $strRenameDatabaseOK = 'Datenbank %s wurde umbenannt zu %s';
 $strRenameTableOK = 'Tabelle %s wurde umbenannt in %s.';
 $strRenameTable = 'Tabelle umbenennen in';
 $strRepairTable = 'Repariere Tabelle';
-$strReplace = 'Ersetzen';
 $strReplaceNULLBy = 'Ersetze NULL durch';
 $strReplaceTable = 'Tabelleninhalt ersetzen';
 $strReset = 'Zurcksetzen';
@@ -650,7 +634,7 @@ $strServerTrafficNotes = '<b>Servertraffic</b>: In diesen Tabellen wird der Netz
 $strServerVars = 'Servervariablen und -einstellungen';
 $strServerVersion = 'Server Version';
 $strSessionValue = 'Wert fr diese Sitzung';
-$strSetEnumVal = 'Wenn das Feld vom Typ \'ENUM\' oder \'SET\' ist, benutzen Sie bitte das Format: \'a\',\'b\',\'c\',....<br />Wann immer Sie ein Backslash ("\") oder ein einfaches Anfhrungszeichen ("\'") verwenden,<br \>setzen Sie bitte ein Backslash vor das Zeichen.  (z.B.: \'\\\\xyz\' or \'a\\\'b\').';
+$strSetEnumVal = 'Wenn das Feld vom Typ \'ENUM\' oder \'SET\' ist, benutzen Sie bitte das Format: \'a\',\'b\',\'c\',... Wann immer Sie ein Backslash ("\") oder ein einfaches Anfhrungszeichen ("\'") verwenden, setzen Sie bitte ein Backslash vor das Zeichen. (z. B.: \'\\\\xyz\' oder \'a\\\'b\').';
 $strShowAll = 'Alles anzeigen';
 $strShowColor = 'mehrfarbig';
 $strShowDatadictAs = 'Format des Strukturverzeichnisses';
@@ -722,10 +706,7 @@ $strTakeIt = 'auswhlen';
 $strTblPrivileges = 'Tabellenspezifische Rechte';
 $strTextAreaLength = 'Wegen seiner Lnge ist dieses<br />Feld vielleicht nicht editierbar.';
 $strThai = 'Thai';
-$strTheContent = 'Der Inhalt Ihrer Datei wurde eingefgt.';
-$strTheContents = 'Der Inhalt der CSV-Datei ersetzt die Eintrge mit den gleichen Primr- oder Unique-Schlsseln.';
 $strTheme = 'Oberflchendesign';
-$strTheTerminator = 'Der Trenner zwischen den Feldern.';
 $strThisHost = 'Dieser Host';
 $strThisNotDirectory = 'Dies ist kein Verzeichnis';
 $strThreadSuccessfullyKilled = 'Der Prozess %s wurde erfolgreich abgebrochen.';
@@ -756,6 +737,7 @@ $strUnicode = 'Unicode';
 $strUnique = 'Unique';
 $strUnknown = 'unbekannt';
 $strUnselectAll = 'Auswahl entfernen';
+$strUnsupportedCompressionDetected = 'Sie haben versucht, eine Datei zu laden, die mit einem nicht untersttzten Verfahren komprimiert wurde (%s). Entweder ist die Untersttzung fr selbiges nicht implementiert oder in IHrer Konfiguration deaktiviert.';
 $strUpdatePrivMessage = 'Die Rechte fr %s wurden gendert.';
 $strUpdateProfileMessage = 'Benutzer wurde gendert.';
 $strUpdateQuery = 'Aktualisieren';
@@ -808,16 +790,193 @@ $strZeroRemovesTheLimit = 'Anmerkung: Der Wert 0 (null) entfernt die Beschrnkung
 $strZip = 'Zip-komprimiert';
 
 // To translate:
+$strAllowInterrupt = 'Abbruch wenn die maximale Scriptlaufzeit errreicht wird. Damit ist es mglich groe Dateien zu importieren, allerdings kann es Transaktionen zerstren.';  //recently translated
+$strAndThen = 'and then';  //to translate
 
-$strPrivDescAlterDb = 'Allows altering the structure of existing tables as well as changing the default charset and collation of databases.';  //to translate
-$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
-$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
-$strPrivDescCreateUser = 'Allows creating, dropping and renaming unser accounts.';  //to translate
-$strPrivDescCreateView = 'Allows creating new views.';  //to translate
-$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
-$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate
+$strBookmarkCreated = 'Bookmark %s gespeichert';  //recently translated
+$strBookmarkReplace = 'berschreibe gleichnamiges Bookmark';  //recently translated
 
-$strRoutines = 'Routines';  //to translate
+$strCompressionWillBeDetected = 'Dateikomprimierung wird automatisch erkannt bei: %s';  //recently translated
+$strCSV = 'CSV';  //recently translated
+$strCSVImportOptions = 'CSV Optionen';  //recently translated
 
+$strDeleteNoUsersSelected = 'Keine Benutzer zum Lschen ausgewhlt!';  //recently translated
+
+$strEnclosingOptional = 'Enclosing of fields is optional';  //to translate
+$strErrorInZipFile = 'Fehler im ZIP-Archive:';  //recently translated
+
+$strFileToImport = 'Datei zum Importieren';  //recently translated
+$strFlushQueryCache = 'Schreibe/Leere den Abfrage-Cache ("FLUSH")';  //recently translated
+$strFlushTables = 'Leeren des gesamten Tabellencaches ("FLUSH")';  //recently translated
+
+$strHandler = 'Handler';  //recently translated
+
+$strIgnoreDuplicates = 'Ignoriere doppelte Zeilen';  //recently translated
+$strImportFinished = 'Der Import wurde erfolgreich beendet.';  //recently translated
+$strImportFormat = 'Dateiformat';  //recently translated
+$strImport = 'Importieren';  //recently translated
+$strInvalidAuthMethod = 'Invalid authentication method set in configuration:';  //to translate
+$strInvalidColumnCount = 'Die Spaltenanzahl muss grer als 0 sein.';  //recently translated
+$strInvalidColumn = 'Ungltige Spalte (%s) angegeben!';  //recently translated
+$strInvalidCSVInput = 'Ungltige CSV Daten, verarbeitung nicht mglich!';  //recently translated
+$strInvalidFieldCount = 'Die Tabelle muss mindestens ein Feld haben.';  //recently translated
+$strInvalidLDIImport = 'Dieses Plugin untersttzt keine Komprimierung!';  //recently translated
+$strInvalidRowNumber = '%d ist keine gltige Zeilennummer.';  //recently translated
+
+$strJoins = 'Tabellenverknpfungen (joins)';  //recently translated
+
+$strKeyCache = 'Schlssel-Cache';  //recently translated
+
+$strLDI = 'CSV mit LOAD DATA';  //recently translated
+$strLDIImportOptions = 'Optionen fr den CSV-Import mit LOAD DATA';  //recently translated
+$strLDILocal = 'mit LOCAL';  //recently translated
+
+$strMaxConnects = 'max. gleichzeitige Verbindungen';  //recently translated
+$strMaximalQueryLength = 'Maximale Lnge der erstellten Abfrage';  //recently translated
+
+$strNoFilesFoundInZip = 'Keine Dateien im ZIP-Archive gefunden!';  //recently translated
+$strNothingToImport = 'Keine Daten zum importieren gefunden!';  //recently translated
+$strNumberOfFields = 'Anzahl der Felder';  //recently translated
+
+$strPartialImport = 'Teilweiser Import';  //recently translated
+$strPrivDescAlterRoutine = 'Erlaubt das Verndern und Lschen von gespeicherten Prozeduren (stored procedures).';  //recently translated
+$strPrivDescCreateRoutine = 'Erlaubt das Erstellen von gespeicherten Prozeduren (stored procedures).';  //recently translated
+$strPrivDescCreateUser = 'Erlaubt das Erstellen, Lschen und Umbenennen von Benutzern.';  //recently translated
+$strPrivDescCreateView = 'Erlaubt das Erstellen von Ansichten (views).';  //recently translated
+$strPrivDescExecute5 = 'Erlaubt das Ausfhren von gespeicherten Prozeduren (stored procedures).';  //recently translated
+$strPrivDescMaxUserConnections = 'Beschrnkt die Anzahl der gleichzeitigen Verbindungen fr diesen Benutzer.';  //recently translated
+$strPrivDescShowView = 'Erlaubt das Abfragen von \'SHOW CREATE VIEW\'.';  //recently translated
+
+$strQueryCache = 'Abfrage-Cache';  //recently translated
+
+$strReplication = 'Replikation';  //recently translated
+$strRunSQLQueryOnServer = 'SQL-Befehl(e) auf Server %s ausfhren';  //recently translated
+
+$strServerStatusDelayedInserts = 'Verzgertes Einfgen (delayed inserts)';  //recently translated
+$strShowingBookmark = 'Showing bookmark';  //to translate
+$strShowOpenTables = 'Zeige alle offenen Tabellen';  //recently translated
+$strShowSlaveHosts = 'Zeige alle Slave-Rechner';  //recently translated
+$strShowSlaveStatus = 'Zeige den Slave-Status';  //recently translated
+$strShowStatusBinlog_cache_disk_useDescr = 'Anzahl der Transaktionen die den Binrylog-Cache verwendet haben aber die Gre des Binarylog-Caches (binlog_cache_size) berschritten haben und eine temporre Datei verwendet haben um die [statements] der Transaktion zu speichern.';  //recently translated
+$strShowStatusBinlog_cache_useDescr = 'Anzahl der Transaktionen, die den temporren Binarylog-Cache verwendet haben.';  //recently translated
+$strShowStatusCreated_tmp_disk_tablesDescr = 'Anzahl der (implizit) auf der Platte erzeugten temporren Tabellen bei der Ausfhrung von Statements. Wenn Created_tmp_disk_tables hoch ist, sollten Sie eventuell die tmp_table_size-Variable herauf setzen, damit temporre Tabellen im Speicher erzeugt werden statt auf der Platte.';  //recently translated
+$strShowStatusCreated_tmp_filesDescr = 'Wieviele temporre Dateien mysqld erzeugt hat.';  //recently translated
+$strShowStatusCreated_tmp_tablesDescr = 'Anzahl der (implizit) im Arbeitsspeicher erzeugten temporren Tabellen bei der Ausfhrung von Statements.';  //recently translated
+$strShowStatusDelayed_errorsDescr = 'Anzahl der Zeilen, die mit INSERT DELAYED geschrieben wurden, und bei denen irgend ein Fehler auftrat (wahrscheinlich duplicate key).';  //recently translated
+$strShowStatusDelayed_insert_threadsDescr = 'Anzahl der verzgerten Insert-Handler-Threads in Benutzung. Jede einzelne Tabelle mit verzgerten Inserts bekommt einen eigenen Thread.';  //recently translated
+$strShowStatusDelayed_writesDescr = 'Anzahl der Zeilen, die mit INSERT DELAYED geschrieben wurden.';  //recently translated
+$strShowStatusFlush_commandsDescr  = 'Anzahl der ausgefhrten FLUSH-Befehle.';  //recently translated
+$strShowStatusHandler_commitDescr = 'Anzahl der Anfragen, ein COMMIT auszufhren.';  //recently translated
+$strShowStatusHandler_deleteDescr = 'Wie oft eine Zeile aus einer Tabelle gelscht wurde.';  //recently translated
+$strShowStatusHandler_discoverDescr = 'Anzahl der gesuchten und gefundenen (discovered) Tabellen. Der MySQL-Server kann das NDB-Cluster-Storage-Engine fragen ob es eine bestimmte Tabelle kennt. Dieser Vorgang wird \'discovery\' genannt.';  //recently translated
+$strShowStatusHandler_read_firstDescr = 'Wie oft der erste Eintrag aus einem Index gelesen wurde. Wenn dieser Wert hoch ist, legt das nahe, dass der Server viele komplette Index-Scans macht (zum Beispiel SELECT spalte1 FROM foo, unter der Annahme, dass spalte1 indiziert ist).';  //recently translated
+$strShowStatusHandler_read_keyDescr = 'Anzahl der Anfragen, eine Zeile basierend auf einem Schlssel zu lesen. Wenn dieser Wert hoch ist, ist das ein gutes Indiz dafr, dass Ihre Anfragen und Tabellen korrekt indiziert sind.';  //recently translated
+$strShowStatusHandler_read_nextDescr = 'Anzahl der Anfragen, die nchste Zeile in der Reihenfolge des Schlssels zu lesen. Dieser Wert wird herauf gezhlt, wenn Sie eine Index-Spalte mit einer Bereichsbeschrnkung (Limit) abfragen. Er wird ebenfalls herauf gezhlt, wenn Sie einen Index-Scan durchfhren.';  //recently translated
+$strShowStatusHandler_read_prevDescr = 'Anzahl der Anfragen, die vorhergehende Zeile in der Reihenfolge des Schlssels zu lesen. Diese Lese-Methode ist hauptschlich zur Optimierung von ORDER BY ... DESC.';  //recently translated
+$strShowStatusHandler_read_rndDescr = 'Anzahl der Anfragen, eine Zeile basierend auf einer festen Position zu lesen. Dieser Wert wird hoch sein, wenn Sie viele Anfragen ausfhren, die erfordern, dass das Ergebnis sortiert wird. Wenn Handler_read_rnd hoch ist, haben Sie wahrscheinlich viele Anfragen, die MySQL zwingen, ganze Tabellen zu scannen, oder Sie haben Joins, die Schlssel nicht richtig benutzen.';  //recently translated
+$strShowStatusHandler_read_rnd_nextDescr = 'Anzahl der Anfragen, die nchste Zeile in der Daten-Datei zu lesen. Dieser Wert wird hoch sein, wenn Sie viele Tabellen-Scans durchfhren. Im Allgemeinen weist das darauf hin, dass Ihre Tabellen nicht korrekt indiziert sind, oder dass Ihre Anfragen nicht so geschrieben sind, dass Sie Vorteile aus den Indexen ziehen, die Sie haben.';  //recently translated
+$strShowStatusHandler_rollbackDescr = 'Anzahl der Anfragen, ein ROLLBACK auszufhren.';  //recently translated
+$strShowStatusHandler_updateDescr = 'Anzahl der Anfragen, eine Zeile in einer Tabelle zu aktualisieren.';  //recently translated
+$strShowStatusHandler_writeDescr = 'Anzahl der Anfragen, eine Zeile in eine Tabelle einzufgen.';  //recently translated
+$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'The number of pages containing data (dirty or clean).';  //to translate
+$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'The number of pages currently dirty.';  //to translate
+$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'The number of buffer pool pages that have been requested to be flushed.';  //to translate
+$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'The number of free pages.';  //to translate
+$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'The number of latched pages in InnoDB buffer pool. These are pages currently being read or written or that can\'t be flushed or removed for some other reason.';  //to translate
+$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'The number of pages busy because they have been allocated for administrative overhead such as row locks or the adaptive hash index. This value can also be calculated as Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';  //to translate
+$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'Total size of buffer pool, in pages.';  //to translate
+$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'The number of "random" read-aheads InnoDB initiated. This happens when a query is to scan a large portion of a table but in random order.';  //to translate
+$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'The number of sequential read-aheads InnoDB initiated. This happens when InnoDB does a sequential full table scan.';  //to translate
+$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'The number of logical read requests InnoDB has done.';  //to translate
+$strShowStatusInnodb_buffer_pool_readsDescr = 'The number of logical reads that InnoDB could not satisfy from buffer pool and had to do a single-page read.';  //to translate
+$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Normally, writes to the InnoDB buffer pool happen in the background. However, if it\'s necessary to read or create a page and no clean pages are available, it\'s necessary to wait for pages to be flushed first. This counter counts instances of these waits. If the buffer pool size was set properly, this value should be small.';  //to translate
+$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'The number writes done to the InnoDB buffer pool.';  //to translate
+$strShowStatusInnodb_data_fsyncsDescr = 'The number of fsync() operations so far.';  //to translate
+$strShowStatusInnodb_data_pending_fsyncsDescr = 'The current number of pending fsync() operations.';  //to translate
+$strShowStatusInnodb_data_pending_readsDescr = 'The current number of pending reads.';  //to translate
+$strShowStatusInnodb_data_pending_writesDescr = 'The current number of pending writes.';  //to translate
+$strShowStatusInnodb_data_readDescr = 'The amount of data read so far, in bytes.';  //to translate
+$strShowStatusInnodb_data_readsDescr = 'The total number of data reads.';  //to translate
+$strShowStatusInnodb_data_writesDescr = 'The total number of data writes.';  //to translate
+$strShowStatusInnodb_data_writtenDescr = 'The amount of data written so far, in bytes.';  //to translate
+$strShowStatusInnodb_dblwr_pages_writtenDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
+$strShowStatusInnodb_dblwr_writesDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
+$strShowStatusInnodb_log_waitsDescr = 'The number of waits we had because log buffer was too small and we had to wait for it to be flushed before continuing.';  //to translate
+$strShowStatusInnodb_log_write_requestsDescr = 'The number of log write requests.';  //to translate
+$strShowStatusInnodb_log_writesDescr = 'The number of physical writes to the log file.';  //to translate
+$strShowStatusInnodb_os_log_fsyncsDescr = 'The number of fsyncs writes done to the log file.';  //to translate
+$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'The number of pending log file fsyncs.';  //to translate
+$strShowStatusInnodb_os_log_pending_writesDescr = 'Pending log file writes.';  //to translate
+$strShowStatusInnodb_os_log_writtenDescr = 'The number of bytes written to the log file.';  //to translate
+$strShowStatusInnodb_pages_createdDescr = 'The number of pages created.';  //to translate
+$strShowStatusInnodb_page_sizeDescr = 'The compiled-in InnoDB page size (default 16KB). Many values are counted in pages; the page size allows them to be easily converted to bytes.';  //to translate
+$strShowStatusInnodb_pages_readDescr = 'The number of pages read.';  //to translate
+$strShowStatusInnodb_pages_writtenDescr = 'The number of pages written.';  //to translate
+$strShowStatusInnodb_row_lock_current_waitsDescr = 'The number of row locks currently being waited for.';  //to translate
+$strShowStatusInnodb_row_lock_time_avgDescr = 'The average time to acquire a row lock, in milliseconds.';  //to translate
+$strShowStatusInnodb_row_lock_timeDescr = 'The total time spent in acquiring row locks, in milliseconds.';  //to translate
+$strShowStatusInnodb_row_lock_time_maxDescr = 'The maximum time to acquire a row lock, in milliseconds.';  //to translate
+$strShowStatusInnodb_row_lock_waitsDescr = 'The number of times a row lock had to be waited for.';  //to translate
+$strShowStatusInnodb_rows_deletedDescr = 'The number of rows deleted from InnoDB tables.';  //to translate
+$strShowStatusInnodb_rows_insertedDescr = 'The number of rows inserted in InnoDB tables.';  //to translate
+$strShowStatusInnodb_rows_readDescr = 'The number of rows read from InnoDB tables.';  //to translate
+$strShowStatusInnodb_rows_updatedDescr = 'The number of rows updated in InnoDB tables.';  //to translate
+$strShowStatusKey_blocks_not_flushedDescr = 'Schlssel-Blcke im Schlssel-Cache, die verndert wurden, aber noch nicht auf die Platte zurck geschrieben (flush). Auch bekannt als Not_flushed_key_blocks.';  //recently translated
+$strShowStatusKey_blocks_unusedDescr = 'Die Anzahl der unbenutzten Schlssel-Blcke im Schlssel-Cache. Dieser Wert kann dazu dienen die Auslastung des Schlssel-Cache zu bestimmen.';  //recently translated
+$strShowStatusKey_blocks_usedDescr = 'Die Anzahl der maximal gleichzeitig benutzten Blocks im Schlssel-Cache.';  //recently translated
+$strShowStatusKey_read_requestsDescr = 'Die Anzahl der Anfragen, einen Schlssel-Block aus dem Cache zu lesen.';  //recently translated
+$strShowStatusKey_readsDescr = 'Die Anzahl physikalischer Lesezugriffen eines Schlssel-Blocks von der Platte. Wenn key_reads hoch ist, ist Ihr key_cache wahrscheinlich zu klein. Die Cache-Zugriffsrate kann mit key_reads / key_read_requests berechnet werden.';  //recently translated
+$strShowStatusKey_write_requestsDescr = 'Die Anzahl der Anfragen, einen Schlssel-Block in den Cache zu schreiben.';  //recently translated
+$strShowStatusKey_writesDescr = 'Die Anzahl physikalischer Schreibvorgnge eines Schlssel-Blocks auf Platte.';  //recently translated
+$strShowStatusLast_query_costDescr = 'Die Kosten fr die zuletzt verarbeitete Abfrage wie vom Abfrage-Optmierer berechnet. Ntzlich um verschiedene Formulierungen fr eine Abfrage zu vergleichen. Der Wert 0 besagt das bisher keine Abfrage bersetzt wurde.';  //recently translated
+$strShowStatusNot_flushed_delayed_rowsDescr = 'Anzahl der Zeilen, die in INSERT DELAY-Warteschleifen darauf warten, geschrieben zu werden.';  //recently translated
+$strShowStatusOpened_tablesDescr = 'Anzahl der Tabellen, die geffnet wurden. Wenn Opened_tables hoch ist, ist Ihre table_cache-Variable wahrscheinlich zu niedrig.';  //recently translated
+$strShowStatusOpen_filesDescr = 'Anzahl der offenen Dateien.';  //recently translated
+$strShowStatusOpen_streamsDescr = 'Anzahl der offenen Streams (hauptschlich zum Loggen benutzt).';  //recently translated
+$strShowStatusOpen_tablesDescr = 'Anzahl der offenen Tabellen.';  //recently translated
+$strShowStatusQcache_free_blocksDescr = 'Freie Speicherblcke im Abfrage-Cache.';  //recently translated
+$strShowStatusQcache_free_memoryDescr = 'Freier Speicher im Abfrage-Cache.';  //recently translated
+$strShowStatusQcache_hitsDescr = 'Abfrage-Cache-Zugriffsrate.';  //recently translated
+$strShowStatusQcache_insertsDescr = 'Die Anzahl der Abfragen die dem Cache hinzugefgt wurden.';  //recently translated
+$strShowStatusQcache_lowmem_prunesDescr = 'Die Anzahl der Abfragen die aus dem Cache entfernt wurden, um Speicher fr neue Abfragen frei zu geben. Dieser Wert kann helfen die Abfrage-Cache-Gre zu optimieren. Der Abfrage-Cache verwendet die \'am wenigsten gebrauchte\' (least recently used (LRU)) Strategie um zu entscheiden welche Abfrage aus dem Cache gelscht werden.';  //recently translated
+$strShowStatusQcache_not_cachedDescr = 'Die Anzahl der nicht im Cache eingetragenen Abfragen (nicht mglich, oder aufgrund der query_cache_type Einstellung).';  //recently translated
+$strShowStatusQcache_queries_in_cacheDescr = 'Die Anzahl der Abfragen im Cache.';  //recently translated
+$strShowStatusQcache_total_blocksDescr = 'Die Anzahl aller Speicherblcke im Abfrage-Cache.';  //recently translated
+$strShowStatusReset = 'Zurcksetzen';  //recently translated
+$strShowStatusRpl_statusDescr = 'Der Status der ausfallsicheren Replikation.';  //recently translated
+$strShowStatusSelect_full_joinDescr = 'Anzahl der Joins ohne Schlssel. Wenn dieser Wert nicht 0 ist sollten die Indizes der Tabellen sorgfltig berprft werden.';  //recently translated
+$strShowStatusSelect_full_range_joinDescr = 'Anzahl der Joins, bei denen eine Bereichssuche auf die Referenztabelle statt fand.';  //recently translated
+$strShowStatusSelect_range_checkDescr = 'Anzahl der Joins ohne Schlssel, bei denen nach jeder Zeile auf Schlsselbenutzung geprft wurde. Wenn dieser Wert nicht 0 ist sollten die Indizes der Tabellen sorgfltig berprft werden.';  //recently translated
+$strShowStatusSelect_rangeDescr = 'Anzahl der Joins, bei denen Bereiche auf die erste Tabelle benutzt wurden. (Es ist normalerweise unkritisch, wenn dieser Wert hoch ist.)';  //recently translated
+$strShowStatusSelect_scanDescr = 'Anzahl der Joins, bei denen die erste Tabelle gescannt wurde.';  //recently translated
+$strShowStatusSlave_open_temp_tablesDescr = 'Anzahl der temporren Tabellen, die momentan vom Slave-Thread geffnet sind.';  //recently translated
+$strShowStatusSlave_retried_transactionsDescr = 'Gesamtzahl (seit Start des Servers) der vom Replikations-Slave-SQL-Thread widerversuchten Transaktionen.';  //recently translated
+$strShowStatusSlave_runningDescr = 'Dieser Wert steht auf ON wenn dieser Server ein Slave ist und mit dem Master verbunden ist.';  //recently translated
+$strShowStatusSlow_launch_threadsDescr = 'Anzahl der Threads, die lnger als slow_launch_time  brauchten, um sich zu verbinden.';  //recently translated
+$strShowStatusSlow_queriesDescr = 'Anzahl der Anfragen, die lnger als long_query_time bentigten.';  //recently translated
+$strShowStatusSort_merge_passesDescr = 'Anzahl der Verschmelzungen (Merge), die von einem Sortiervorgang bentigt wurden. Wenn dieser Wert hoch ist, sollten Sie in Betracht ziehen, sort_buffer  herauf zu setzen.';  //recently translated
+$strShowStatusSort_rangeDescr = 'Anzahl der Sortiervorgnge, die mit Bereichen durchgefhrt wurden.';  //recently translated
+$strShowStatusSort_rowsDescr = 'Anzahl der sortierten Zeilen.';  //recently translated
+$strShowStatusSort_scanDescr = 'Anzahl der Sortiervorgnge, die durchgefhrt wurden, indem die Tabelle gescannt wurde.';  //recently translated
+$strShowStatusTable_locks_immediateDescr = 'Wie oft eine Tabellensperre sofort erlangt wurde.';  //recently translated
+$strShowStatusTable_locks_waitedDescr = 'Wie oft eine Tabellensperre nicht sofort erlangt werden konnte und gewartet werden musst. Wenn dieser Wert hoch ist und Sie Performance-Probleme haben, sollten Sie zunchst Ihre Anfragen optimieren und dann entweder Ihre Tabelle(n) zerteilen oder Replikation benutzen.';  //recently translated
+$strShowStatusThreads_cachedDescr = 'Anzahl der Threads im Thread-Cache. Die Cache-Zugriffsrate kann mit Threads_created / Connections berechnet werden. Wenn dieser Wert rot ist, sollte der thread_cache_size erhht werden.';  //recently translated
+$strShowStatusThreads_connectedDescr = 'Anzahl der momentan offenen Verbindungen.';  //recently translated
+$strShowStatusThreads_createdDescr = 'Anzahl der Threads, die zur Handhabung von Verbindungen erzeugt wurden. Wenn Threads_created hoch ist, sollten Sie eventuell die Thread_cache_size-Variable herauf setzen. (Normalerweise ergibt sich daraus keine bemerkbare Performance-Steigerung wenn eine gute Thread-Implementierung vorliegt.)';  //recently translated
+$strShowStatusThreads_runningDescr = 'Anzahl der Threads, die nicht schlafen.';  //recently translated
+$strSkipQueries = 'Anzahl der am Anfang zu berspringenden Eintrge (Abfragen)';  //recently translated
+$strSorting = 'Sortierung';  //recently translated
+
+$strTableAlreadyExists = 'Die Tabelle %s existiert bereits!';  //recently translated
+$strTempData = 'Temporre Daten';  //recently translated
+$strThreads = 'Prozesse';  //recently translated
+$strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
+$strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
+$strTimeoutPassed = 'Script timeout passed, if you want to finish import, please resubmit same file and import will resume.';  //to translate
+$strTransactionCoordinator = 'Transaction coordinator';  //to translate
 $strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data.';  //to translate
+$strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate
+
+$strUploadLimit = 'Mglicherweise wurde eine zu groe Datei hochgeladen. Bitte schauen Sie in die %sDokumentation%s zur Lsung diese Problems.';  //recently translated
+
 ?>
