@@ -1,5 +1,5 @@
 <?php
-/* $Id: tatarish-iso-8859-9.inc.php,v 1.3 2005/06/12 10:10:11 swix Exp $ */
+/* $Id: tatarish-iso-8859-9.inc.php,v 1.26 2005/10/30 10:03:50 nijel Exp $ */
 
 $charset = 'iso-8859-9';
 $allow_recoding = TRUE;
@@ -84,7 +84,6 @@ $strBinaryLog = 'Binar kndlek';
 $strBookmarkAllUsers = 'Bu taman bar qullanua da irele itse';
 $strBookmarkDeleted = 'Tama beterelde.';
 $strBookmarkLabel = 'Yarlq';
-$strBookmarkOptions = 'Tamalaw caylaw';
 $strBookmarkQuery = 'Tamalanan SQL-soraw';
 $strBookmarkThis = 'Bu SQL-sorawa tama quy';
 $strBookmarkView = 'Kr gen';
@@ -110,7 +109,6 @@ $strCantLoadRecodeIconv = 'Can not load iconv or recode extension needed for cha
 $strCantRenameIdxToPrimary = 'Aqn "PRIMARY" itep atap bulm!';
 $strCantUseRecodeIconv = 'Can not use iconv nor libiconv nor recode_string function while extension reports to be loaded. Check your php configuration.';
 $strCardinality = 'Qabatlanu san';
-$strCarriage = 'Yul ker: \\r';
 $strCaseInsensitive = 'kee/ol sizmw';
 $strCaseSensitive = 'kee/ol siz';
 $strCentralEuropean = 'zk Awrup';
@@ -313,7 +311,6 @@ $strHungarian = 'Macara';
 $strIcelandic = 'clanda';
 $strId = 'ID';
 $strIdxFulltext = 'Tulmten';
-$strIfYouWish = 'Table baanlarn qauberlren gen yklrg telise ikn, ter-aral isemlek kert.';
 $strIgnore = 'Qarama';
 $strIgnoreInserts = '"IGNORE" beln kertse';
 $strIgnoringFile = '"%s" bireme tel';
@@ -342,12 +339,9 @@ $strInnodbStat = 'InnoDB Xlte';
 $strInsecureMySQL = 'Caylaw biremed, MySQL\'a ire en dti xsap kertelgn (serszsez "root"). MySQL-servere ul dti caylawlar beln alan, and xl iminlikne citdi tiege tip sanala.';
 $strInsert = 'stw';
 $strInsertAsNewRow = 'Yaa kertem kert t';
-$strInsertBookmarkTitle = 'Tama adn kertse';
 $strInsertNewRow = 'Yaa kertem tu';
-$strInsertTextfiles = 'Table een mtenle birem etlegen yklw';
 $strInsertedRowId = 'Kertelgn yazman id:';
 $strInsertedRows = 'Kertelgn yazma:';
-$strInstructions = 'merlr';
 $strInternalNotNecessary = '* InnoDB eend bulan eke bylnelr qabatlaw kirk tgel.';
 $strInternalRelations = 'Eke bylnelr';
 
@@ -375,13 +369,10 @@ $strLatexStructure = '__TABLE__ table tzelee';
 $strLatvian = 'Lata';
 $strLengthSet = 'Oznlq/By*';
 $strLimitNumRows = 'Bit sayn Kertem san';
-$strLineFeed = 'Yulara: \\n';
 $strLinesTerminatedBy = 'Yul ara bilgese';
 $strLinkNotFound = 'Bylne tablmad';
 $strLinksTo = 'Bon beln bylne:';
 $strLithuanian = 'Lithuana';
-$strLoadExplanation = 'The best method is checked by default, but you can change if it fails.';
-$strLoadMethod = 'LOAD sul';
 $strLocalhost = 'Cirle';
 $strLocationTextfile = 'Mten biremene urnalu';
 $strLogPassword = 'Sersz:';
@@ -409,12 +400,10 @@ $strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP con
 $strModifications = 'zgrtlr saqland';
 $strModify = 'zgrt';
 $strModifyIndexTopic = 'Aq zgrt';
-$strMoreStatusVars = 'Baqa xlt zgrmlre';
 $strMoveTable = 'Boa ker (biremlek<b>.</b>table):';
 $strMoveTableOK = '"%s" atl table "%s" keek atald.';
 $strMoveTableSameNames = 'Ber k at beln table kerep bulm!';
 $strMultilingual = 'kptelle';
-$strMustSelectFile = '`Birem etlegen stw en, an isemen sayls bar..';
 $strMyISAMDataPointerSize = 'Data pointer oll';
 $strMyISAMDataPointerSizeDesc = 'MAX_ROWS kylmse bylngn oraqta, CREATE TABLE aa MyISAM table qoranda qullanas pointerne baytl oll.';
 $strMyISAMMaxExtraSortFileSize = 'Aq yasaw en waqtl birem olln lw';
@@ -437,7 +426,6 @@ $strMySQLShowStatus = 'MySQL ewaqt';
 $strMySQLShowVars = 'MySQL zgrmlre';
 
 $strName = 'sem';
-$strNeedPrimaryKey = 'Bu table en tp aq qoras bar.';
 $strNext = 'Kilse';
 $strNo = 'yuq';
 $strNoActivity = 'No activity since %s seconds or more, please login again';
@@ -456,7 +444,6 @@ $strNoPassword = 'Serszsez';
 $strNoPermission = 'The web server does not have permission to save the file %s.';
 $strNoPhp = 'PHP Kodsz';
 $strNoPrivileges = 'Xoquqsz';
-$strNoQuery = 'SQL soraw tgel!';
 $strNoRights = 'Bonda bulu en, xoquqlar citmi!';
 $strNoRowsSelected = 'Kertemnr saylad';
 $strNoSpace = '"%s" biremen saqlaw en bu ara citmi.';
@@ -468,19 +455,15 @@ $strNone = 'Yuq';
 $strNotNumber = 'San tgel bu!';
 $strNotOK = 'OK tgel';
 $strNotSet = '<b>%s</b> atl table yuq, y ki "%s" tezmsen kermi';
-$strNotValidNumber = ' ul kertem san tgel!';
 $strNull = 'Null';
 $strNumSearchResultsInTable = '%s kile bar <i>%s</i> table\'da';
 $strNumSearchResultsTotal = '<b>Tulaym:</b> <i>%s</i> kile';
 $strNumTables = 'Table';
 
 $strOK = 'OK';
-$strOftenQuotation = 'Often quotation marks. OPTIONALLY means that only char and varchar fields are enclosed by the "enclosed by"-character.';
 $strOperations = 'ml';
 $strOperator = 'Operator';
 $strOptimizeTable = 'Optimize table';
-$strOptionalControls = 'Optional. Controls how to write or read special characters.';
-$strOptionally = 'MHM TGEL';
 $strOr = 'Y';
 $strOverhead = 'Overhead';
 $strOverwriteExisting = 'Birem bar bulsa, stn yazdras';
@@ -520,7 +503,6 @@ $strPrintView = 'Bastru krenee';
 $strPrintViewFull = 'Bastru krenee (bar mtennr beln)';
 $strPrivDescAllPrivileges = 'GRANT\'tan basqa bar xoquqlar da bar.';
 $strPrivDescAlter = 'Bired bulan table tzeleen zgrt xoquq.';
-$strPrivDescAlterDb = 'Bar bulan table tzeleen d, dti bilgelm beln tez trtiben d zgrterg bir.';
 $strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';
 $strPrivDescCreateDb = 'Yaa biremlek/table yasaw xoquq.';
 $strPrivDescCreateRoutine = 'Saqlanan funkslar qorra bir.';
@@ -589,7 +571,6 @@ $strRenameDatabaseOK = '"%s" biremlegen "%s" at quld';
 $strRenameTable = 'Table ismen zgrt';
 $strRenameTableOK = '"%s" table\'na "%s" at quld';
 $strRepairTable = 'Table tzet';
-$strReplace = 'Almatr';
 $strReplaceNULLBy = 'NULL\'n almatras:';
 $strReplaceTable = 'Table etlegen bu biremlektge beln alamtras';
 $strReset = 'Awdar';
@@ -599,7 +580,6 @@ $strRevokeAndDelete = 'Bu qullanularn xoquqlarn awdarp beterse.';
 $strRevokeAndDeleteDescr = 'The users will still have the USAGE privilege until the privileges are reloaded.';
 $strRevokeMessage = 'You have revoked the privileges for %s';
 $strRomanian = 'Romana';
-$strRoutines = 'Funkslar';
 $strRowLength = 'Kertem oznl';
 $strRowSize = ' Kerem zurl';
 $strRows = 'Kerem';
@@ -719,9 +699,6 @@ $strTakeIt = 'bon sayla';
 $strTblPrivileges = 'Berr table en xoquqlar';
 $strTextAreaLength = ' Because of its length,<br /> this field might not be editable';
 $strThai = 'Taya';
-$strTheContent = 'Biremene etlege stlende.';
-$strTheContents = 'The contents of the file replaces the contents of the selected table for rows with identical primary or unique key.';
-$strTheTerminator = 'Alannarn ayr.';
 $strTheme = 'Tlaw / Bizle';
 $strThisHost = 'Bu Sanaq';
 $strThisNotDirectory = 'Trgk tgel ul';
@@ -743,7 +720,6 @@ $strTransformation_text_plain__formatted = 'Preserves original formatting of the
 $strTransformation_text_plain__imagelink = 'Displays an image and a link, the field contains the filename; first option is a prefix like "http://domain.com/", second option is the width in pixels, third is the height.';
 $strTransformation_text_plain__link = 'Displays a link, the field contains the filename; first option is a prefix like "http://domain.com/", second option is a title for the link.';
 $strTransformation_text_plain__substr = 'Only shows part of a string. First option is an offset to define where the output of your text starts (Default 0). Second option is an offset how much text is returned. If empty, returns all the remaining text. The third option defines which chars will be appended to the output when a substring is returned (Default: ...) .';
-$strTransformation_text_plain__unformatted = 'HTML etlege HTML bermleklr aa krstel. HTML tzelee krstelmi.';
 $strTruncateQueries = 'Sorawn Qsqartp Krstse';
 $strTurkish = 'Trek';
 $strType = 'Tre';
@@ -812,4 +788,171 @@ $strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to transl
 $strGeneratePassword = 'Generate Password';  //to translate
 $strGenerate = 'Generate';  //to translate
 $strCopy = 'Copy';  //to translate
+$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data.';  //to translate
+$strInvalidFieldCount = 'Table must have at least one field.';  //to translate
+$strInvalidRowNumber = '%d is not valid row number.';  //to translate
+$strInvalidColumnCount = 'Column count has to be larger than zero.';  //to translate
+$strInvalidFieldAddCount = 'You have to add at least one field.';  //to translate
+$strAndThen = 'and then';  //to translate
+$strInvalidAuthMethod = 'Invalid authentication method set in configuration:';  //to translate
+$strRunSQLQueryOnServer = 'Run SQL query/queries on server %s';  //to translate
+$strCSV = 'CSV';  //to translate
+$strImport = 'Import';  //to translate
+$strImportFormat = 'Format of imported file';  //to translate
+$strFileToImport = 'File to import';  //to translate
+$strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
+$strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
+$strEnclosingOptional = 'Enclosing of fields is optional';  //to translate
+$strCSVImportOptions = 'CSV options';  //to translate
+$strPartialImport = 'Partial import';  //to translate
+$strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate
+$strTimeoutPassed = 'Script timeout passed, if you want to finish import, please resubmit same file and import will resume.';  //to translate
+$strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
+$strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
+$strUnsupportedCompressionDetected = 'You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.';  //to translate
+$strNothingToImport = 'You didn\'t enter any data to import!';  //to translate
+$strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
+$strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
+$strInvalidColumn = 'Invalid column (%s) specified!';  //to translate
+$strInvalidCSVInput = 'Invalid CSV input, could not parse!';  //to translate
+$strNoFilesFoundInZip = 'No files found inside ZIP archive!';  //to translate
+$strErrorInZipFile = 'Error in ZIP archive:';  //to translate
+$strFlushQueryCache = 'Flush query cache';  //to translate
+$strFlushTables = 'Flush (close) all tables';  //to translate
+$strHandler = 'Handler';  //to translate
+$strJoins = 'Joins';  //to translate
+$strKeyCache = 'Key cache';  //to translate
+$strMaxConnects = 'max. concurrent connections';  //to translate
+$strQueryCache = 'Query cache';  //to translate
+$strReplication = 'Replication';  //to translate
+$strServerStatusDelayedInserts = 'Delayed inserts';  //to translate
+$strShowOpenTables = 'Show open tables';  //to translate
+$strShowSlaveHosts = 'Show slave hosts';  //to translate
+$strShowSlaveStatus = 'Show slave status';  //to translate
+$strShowStatusReset = 'Reset';  //to translate
+$strShowStatusBinlog_cache_disk_useDescr = 'The number of transactions that used the temporary binary log cache but that exceeded the value of binlog_cache_size and used a temporary file to store statements from the transaction.';  //to translate
+$strShowStatusBinlog_cache_useDescr = 'The number of transactions that used the temporary binary log cache.';  //to translate
+$strShowStatusCreated_tmp_disk_tablesDescr = 'The number of temporary tables on disk created automatically by the server while executing statements. If Created_tmp_disk_tables is big, you may want to increase the tmp_table_size  value to cause temporary tables to be memory-based instead of disk-based.';  //to translate
+$strShowStatusCreated_tmp_filesDescr = 'How many temporary files mysqld has created.';  //to translate
+$strShowStatusCreated_tmp_tablesDescr = 'The number of in-memory temporary tables created automatically by the server while executing statements.';  //to translate
+$strShowStatusDelayed_errorsDescr = 'The number of rows written with INSERT DELAYED for which some error occurred (probably duplicate key).';  //to translate
+$strShowStatusDelayed_insert_threadsDescr = 'The number of INSERT DELAYED handler threads in use. Every different table on which one uses INSERT DELAYED gets its own thread.';  //to translate
+$strShowStatusDelayed_writesDescr = 'The number of INSERT DELAYED rows written.';  //to translate
+$strShowStatusFlush_commandsDescr  = 'The number of executed FLUSH statements.';  //to translate
+$strShowStatusHandler_commitDescr = 'The number of internal COMMIT statements.';  //to translate
+$strShowStatusHandler_deleteDescr = 'The number of times a row was deleted from a table.';  //to translate
+$strShowStatusHandler_discoverDescr = 'The MySQL server can ask the NDB Cluster storage engine if it knows about a table with a given name. This is called discovery. Handler_discover indicates the number of time tables have been discovered.';  //to translate
+$strShowStatusHandler_read_firstDescr = 'The number of times the first entry was read from an index. If this is high, it suggests that the server is doing a lot of full index scans; for example, SELECT col1 FROM foo, assuming that col1 is indexed.';  //to translate
+$strShowStatusHandler_read_keyDescr = 'The number of requests to read a row based on a key. If this is high, it is a good indication that your queries and tables are properly indexed.';  //to translate
+$strShowStatusHandler_read_nextDescr = 'The number of requests to read the next row in key order. This is incremented if you are querying an index column with a range constraint or if you are doing an index scan.';  //to translate
+$strShowStatusHandler_read_prevDescr = 'The number of requests to read the previous row in key order. This read method is mainly used to optimize ORDER BY ... DESC.';  //to translate
+$strShowStatusHandler_read_rndDescr = 'The number of requests to read a row based on a fixed position. This is high if you are doing a lot of queries that require sorting of the result. You probably have a lot of queries that require MySQL to scan whole tables or you have joins that don\'t use keys properly.';  //to translate
+$strShowStatusHandler_read_rnd_nextDescr = 'The number of requests to read the next row in the data file. This is high if you are doing a lot of table scans. Generally this suggests that your tables are not properly indexed or that your queries are not written to take advantage of the indexes you have.';  //to translate
+$strShowStatusHandler_rollbackDescr = 'The number of internal ROLLBACK statements.';  //to translate
+$strShowStatusHandler_updateDescr = 'The number of requests to update a row in a table.';  //to translate
+$strShowStatusHandler_writeDescr = 'The number of requests to insert a row in a table.';  //to translate
+$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'The number of pages containing data (dirty or clean).';  //to translate
+$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'The number of pages currently dirty.';  //to translate
+$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'The number of buffer pool pages that have been requested to be flushed.';  //to translate
+$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'The number of free pages.';  //to translate
+$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'The number of latched pages in InnoDB buffer pool. These are pages currently being read or written or that can\'t be flushed or removed for some other reason.';  //to translate
+$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'The number of pages busy because they have been allocated for administrative overhead such as row locks or the adaptive hash index. This value can also be calculated as Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';  //to translate
+$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'Total size of buffer pool, in pages.';  //to translate
+$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'The number of "random" read-aheads InnoDB initiated. This happens when a query is to scan a large portion of a table but in random order.';  //to translate
+$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'The number of sequential read-aheads InnoDB initiated. This happens when InnoDB does a sequential full table scan.';  //to translate
+$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'The number of logical read requests InnoDB has done.';  //to translate
+$strShowStatusInnodb_buffer_pool_readsDescr = 'The number of logical reads that InnoDB could not satisfy from buffer pool and had to do a single-page read.';  //to translate
+$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Normally, writes to the InnoDB buffer pool happen in the background. However, if it\'s necessary to read or create a page and no clean pages are available, it\'s necessary to wait for pages to be flushed first. This counter counts instances of these waits. If the buffer pool size was set properly, this value should be small.';  //to translate
+$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'The number writes done to the InnoDB buffer pool.';  //to translate
+$strShowStatusInnodb_data_fsyncsDescr = 'The number of fsync() operations so far.';  //to translate
+$strShowStatusInnodb_data_pending_fsyncsDescr = 'The current number of pending fsync() operations.';  //to translate
+$strShowStatusInnodb_data_pending_readsDescr = 'The current number of pending reads.';  //to translate
+$strShowStatusInnodb_data_pending_writesDescr = 'The current number of pending writes.';  //to translate
+$strShowStatusInnodb_data_readDescr = 'The amount of data read so far, in bytes.';  //to translate
+$strShowStatusInnodb_data_readsDescr = 'The total number of data reads.';  //to translate
+$strShowStatusInnodb_data_writesDescr = 'The total number of data writes.';  //to translate
+$strShowStatusInnodb_data_writtenDescr = 'The amount of data written so far, in bytes.';  //to translate
+$strShowStatusInnodb_dblwr_pages_writtenDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
+$strShowStatusInnodb_dblwr_writesDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
+$strShowStatusInnodb_log_waitsDescr = 'The number of waits we had because log buffer was too small and we had to wait for it to be flushed before continuing.';  //to translate
+$strShowStatusInnodb_log_write_requestsDescr = 'The number of log write requests.';  //to translate
+$strShowStatusInnodb_log_writesDescr = 'The number of physical writes to the log file.';  //to translate
+$strShowStatusInnodb_os_log_fsyncsDescr = 'The number of fsyncs writes done to the log file.';  //to translate
+$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'The number of pending log file fsyncs.';  //to translate
+$strShowStatusInnodb_os_log_pending_writesDescr = 'Pending log file writes.';  //to translate
+$strShowStatusInnodb_os_log_writtenDescr = 'The number of bytes written to the log file.';  //to translate
+$strShowStatusInnodb_page_sizeDescr = 'The compiled-in InnoDB page size (default 16KB). Many values are counted in pages; the page size allows them to be easily converted to bytes.';  //to translate
+$strShowStatusInnodb_pages_createdDescr = 'The number of pages created.';  //to translate
+$strShowStatusInnodb_pages_readDescr = 'The number of pages read.';  //to translate
+$strShowStatusInnodb_pages_writtenDescr = 'The number of pages written.';  //to translate
+$strShowStatusInnodb_row_lock_current_waitsDescr = 'The number of row locks currently being waited for.';  //to translate
+$strShowStatusInnodb_row_lock_timeDescr = 'The total time spent in acquiring row locks, in milliseconds.';  //to translate
+$strShowStatusInnodb_row_lock_time_avgDescr = 'The average time to acquire a row lock, in milliseconds.';  //to translate
+$strShowStatusInnodb_row_lock_time_maxDescr = 'The maximum time to acquire a row lock, in milliseconds.';  //to translate
+$strShowStatusInnodb_row_lock_waitsDescr = 'The number of times a row lock had to be waited for.';  //to translate
+$strShowStatusInnodb_rows_deletedDescr = 'The number of rows deleted from InnoDB tables.';  //to translate
+$strShowStatusInnodb_rows_insertedDescr = 'The number of rows inserted in InnoDB tables.';  //to translate
+$strShowStatusInnodb_rows_readDescr = 'The number of rows read from InnoDB tables.';  //to translate
+$strShowStatusInnodb_rows_updatedDescr = 'The number of rows updated in InnoDB tables.';  //to translate
+$strShowStatusKey_blocks_not_flushedDescr = 'The number of key blocks in the key cache that have changed but haven\'t yet been flushed to disk. It used to be known as Not_flushed_key_blocks.';  //to translate
+$strShowStatusKey_blocks_unusedDescr = 'The number of unused blocks in the key cache. You can use this value to determine how much of the key cache is in use.';  //to translate
+$strShowStatusKey_blocks_usedDescr = 'The number of used blocks in the key cache. This value is a high-water mark that indicates the maximum number of blocks that have ever been in use at one time.';  //to translate
+$strShowStatusKey_read_requestsDescr = 'The number of requests to read a key block from the cache.';  //to translate
+$strShowStatusKey_readsDescr = 'The number of physical reads of a key block from disk. If Key_reads is big, then your key_buffer_size value is probably too small. The cache miss rate can be calculated as Key_reads/Key_read_requests.';  //to translate
+$strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
+$strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
+$strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
+$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
+$strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
+$strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
+$strShowStatusOpen_tablesDescr = 'The number of tables that are open.';  //to translate
+$strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
+$strShowStatusQcache_free_blocksDescr = 'The number of free memory blocks in query cache.';  //to translate
+$strShowStatusQcache_free_memoryDescr = 'The amount of free memory for query cache.';  //to translate
+$strShowStatusQcache_hitsDescr = 'The number of cache hits.';  //to translate
+$strShowStatusQcache_insertsDescr = 'The number of queries added to the cache.';  //to translate
+$strShowStatusQcache_lowmem_prunesDescr = 'The number of queries that have been removed from the cache to free up memory for caching new queries. This information can help you tune the query cache size. The query cache uses a least recently used (LRU) strategy to decide which queries to remove from the cache.';  //to translate
+$strShowStatusQcache_not_cachedDescr = 'The number of non-cached queries (not cachable, or not cached due to the query_cache_type setting).';  //to translate
+$strShowStatusQcache_queries_in_cacheDescr = 'The number of queries registered in the cache.';  //to translate
+$strShowStatusQcache_total_blocksDescr = 'The total number of blocks in the query cache.';  //to translate
+$strShowStatusRpl_statusDescr = 'The status of failsafe replication (not yet implemented).';  //to translate
+$strShowStatusSelect_full_joinDescr = 'The number of joins that do not use indexes. If this value is not 0, you should carefully check the indexes of your tables.';  //to translate
+$strShowStatusSelect_full_range_joinDescr = 'The number of joins that used a range search on a reference table.';  //to translate
+$strShowStatusSelect_rangeDescr = 'The number of joins that used ranges on the first table. (It\'s normally not critical even if this is big.)';  //to translate
+$strShowStatusSelect_range_checkDescr = 'The number of joins without keys that check for key usage after each row. (If this is not 0, you should carefully check the indexes of your tables.)';  //to translate
+$strShowStatusSelect_scanDescr = 'The number of joins that did a full scan of the first table.';  //to translate
+$strShowStatusSlave_open_temp_tablesDescr = 'The number of temporary tables currently open by the slave SQL thread.';  //to translate
+$strShowStatusSlave_retried_transactionsDescr = 'Total (since startup) number of times the replication slave SQL thread has retried transactions.';  //to translate
+$strShowStatusSlave_runningDescr = 'This is ON if this server is a slave that is connected to a master.';  //to translate
+$strShowStatusSlow_launch_threadsDescr = 'The number of threads that have taken more than slow_launch_time seconds to create.';  //to translate
+$strShowStatusSlow_queriesDescr = 'The number of queries that have taken more than long_query_time seconds.';  //to translate
+$strShowStatusSort_merge_passesDescr = 'The number of merge passes the sort algorithm has had to do. If this value is large, you should consider increasing the value of the sort_buffer_size system variable.';  //to translate
+$strShowStatusSort_rangeDescr = 'The number of sorts that were done with ranges.';  //to translate
+$strShowStatusSort_rowsDescr = 'The number of sorted rows.';  //to translate
+$strShowStatusSort_scanDescr = 'The number of sorts that were done by scanning the table.';  //to translate
+$strShowStatusTable_locks_immediateDescr = 'The number of times that a table lock was acquired immediately.';  //to translate
+$strShowStatusTable_locks_waitedDescr = 'The number of times that a table lock could not be acquired immediately and a wait was needed. If this is high, and you have performance problems, you should first optimize your queries, and then either split your table or tables or use replication.';  //to translate
+$strShowStatusThreads_cachedDescr = 'The number of threads in the thread cache. The cache hit rate can be calculated as Threads_created/Connections. If this value is red you should raise your thread_cache_size.';  //to translate
+$strShowStatusThreads_connectedDescr = 'The number of currently open connections.';  //to translate
+$strShowStatusThreads_createdDescr = 'The number of threads created to handle connections. If Threads_created is big, you may want to increase the thread_cache_size value. (Normally this doesn\'t give a notable performance improvement if you have a good thread implementation.)';  //to translate
+$strShowStatusThreads_runningDescr = 'The number of threads that are not sleeping.';  //to translate
+$strSorting = 'Sorting';  //to translate
+$strTempData = 'Temporary data';  //to translate
+$strThreads = 'Threads';  //to translate
+$strLDI = 'CSV using LOAD DATA';  //to translate
+$strLDILocal = 'Use LOCAL keyword';  //to translate
+$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
+$strInvalidLDIImport = 'This plugin does not support compressed imports!';  //to translate
+$strTableAlreadyExists = 'Table %s already exists!';  //to translate
+$strTransactionCoordinator = 'Transaction coordinator';  //to translate
+$strNumberOfFields = 'Number of fields';  //to translate
+$strShowingBookmark = 'Showing bookmark';  //to translate
+$strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';  //to translate
+$strDeleteNoUsersSelected = 'No users selected for deleting!';  //to translate
+$strPrivDescMaxUserConnections = 'Limits the number of simultaneous connections the user may have.';  //to translate
+$strMaximalQueryLength = 'Maximal length of created query';  //to translate
+$strBookmarkCreated = 'Bookmark %s created';  //to translate
+$strBookmarkReplace = 'Replace existing bookmark of same name';  //to translate
+$strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate
+$strEsperanto = 'Esperanto';  //to translate
 ?>
